/*
 * Nextcloud Android Library
 *
 * SPDX-FileCopyrightText: 2022-2024 Nextcloud GmbH and Nextcloud contributors
 * SPDX-FileCopyrightText: 2022 Tobias Kaminsky <tobias@kaminsky.me>
 * SPDX-License-Identifier: MIT
 */
package com.owncloud.android.lib.resources.shares

import junit.framework.Assert.assertEquals
import junit.framework.Assert.assertTrue
import org.junit.Test

@Suppress("LargeClass", "LongMethod")
class ShareXMLParserIT {
    @Test
    fun testOCShareResponse() {
        val xml = """<?xml version="1.0"?>
<ocs>
 <meta>
  <status>ok</status>
  <statuscode>200</statuscode>
  <message>OK</message>
 </meta>
 <data>
  <element>
   <element>
    <id>2521</id>
    <share_type>0</share_type>
    <uid_owner>test</uid_owner>
    <displayname_owner>Test Kaminsky</displayname_owner>
    <permissions>31</permissions>
    <can_edit>1</can_edit>
    <can_delete>1</can_delete>
    <stime>1663581736</stime>
    <parent/>
    <expiration>2023-02-16 00:00:00</expiration>
    <token/>
    <uid_file_owner>test</uid_file_owner>
    <note></note>
    <label/>
    <displayname_file_owner>Test Kaminsky</displayname_file_owner>
    <path>/shareToAdminFavorite</path>
    <item_type>folder</item_type>
    <mimetype>httpd/unix-directory</mimetype>
    <has_preview></has_preview>
    <storage_id>home::test</storage_id>
    <storage>9</storage>
    <item_source>267098</item_source>
    <file_source>267098</file_source>
    <file_parent>23982</file_parent>
    <file_target>/shareToAdminFavorite</file_target>
    <share_with>admin</share_with>
    <share_with_displayname>Administrator</share_with_displayname>
    <share_with_displayname_unique>admin@next.cloud</share_with_displayname_unique>
    <status>
     <status>dnd</status>
     <message/>
     <icon/>
     <clearAt/>
    </status>
    <mail_send>0</mail_send>
    <hide_download>0</hide_download>
    <attributes/>
    <tags>
     <element>_${'$'}!&lt;Favorite&gt;!$\_</element>
    </tags>
   </element>
  </element>
 </data>
</ocs>
"""
        val sut = ShareToRemoteOperationResultParser(ShareXMLParser())
        val shares = sut.parse(xml)

        assertEquals(1, shares.resultData.size)
        assertTrue(shares.resultData[0].isFavorite)
    }

    @Test
    @Suppress("MagicNumber")
    fun testOCShareResponse2() {
        val xml = """<?xml version="1.0"?>
<ocs>
	<meta>
		<status>ok</status>
		<statuscode>200</statuscode>
		<message>OK</message>
	</meta>
	<data>
		<element>
			<id>8</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1515155801</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/allTypes/share/shared.jpg</path>
			<item_type>file</item_type>
			<mimetype>image/jpeg</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>265</item_source>
			<file_source>265</file_source>
			<file_parent>21376</file_parent>
			<file_target>/1.jpg</file_target>
			<share_with>admin</share_with>
			<share_with_displayname>Administrator</share_with_displayname>
			<share_with_displayname_unique>admin@next.cloud</share_with_displayname_unique>
			<status>
				<status>dnd</status>
				<message/>
				<icon/>
				<clearAt/>
			</status>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>11</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1518445486</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>Tobi Kaminsky</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi Kaminsky</displayname_file_owner>
			<path>/allTypes/share/ShareAble</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>shared::/allTypes/share/ShareAble</storage_id>
			<storage>4</storage>
			<item_source>246</item_source>
			<file_source>246</file_source>
			<file_parent>21376</file_parent>
			<file_target>/ShareAble</file_target>
			<share_with>admin</share_with>
			<share_with_displayname>Administrator</share_with_displayname>
			<share_with_displayname_unique>admin@next.cloud</share_with_displayname_unique>
			<status>
				<status>dnd</status>
				<message/>
				<icon/>
				<clearAt/>
			</status>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>16</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>31</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1521185829</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/sync/1/user</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>23881</item_source>
			<file_source>23881</file_source>
			<file_parent>73025</file_parent>
			<file_target>/2</file_target>
			<share_with>admin</share_with>
			<share_with_displayname>Administrator</share_with_displayname>
			<share_with_displayname_unique>admin@next.cloud</share_with_displayname_unique>
			<status>
				<status>dnd</status>
				<message/>
				<icon/>
				<clearAt/>
			</status>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>18</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>31</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1521193185</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/sync/LinkUserGroup</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>23962</item_source>
			<file_source>23962</file_source>
			<file_parent>23880</file_parent>
			<file_target>/LinkUserGroup</file_target>
			<share_with>admin</share_with>
			<share_with_displayname>Administrator</share_with_displayname>
			<share_with_displayname_unique>admin@next.cloud</share_with_displayname_unique>
			<status>
				<status>dnd</status>
				<message/>
				<icon/>
				<clearAt/>
			</status>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>306</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1526310608</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/_act/test.txt</path>
			<item_type>file</item_type>
			<mimetype>text/plain</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>32368</item_source>
			<file_source>32368</file_source>
			<file_parent>31797</file_parent>
			<file_target>/test.txt</file_target>
			<share_with>admin</share_with>
			<share_with_displayname>Administrator</share_with_displayname>
			<share_with_displayname_unique>admin@next.cloud</share_with_displayname_unique>
			<status>
				<status>dnd</status>
				<message/>
				<icon/>
				<clearAt/>
			</status>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>308</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1526311765</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/_act/test.txt</path>
			<item_type>file</item_type>
			<mimetype>text/plain</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>32368</item_source>
			<file_source>32368</file_source>
			<file_parent>31797</file_parent>
			<file_target>/test.txt</file_target>
			<share_with>Tobi Kaminsky</share_with>
			<share_with_displayname>Tobi Kaminsky</share_with_displayname>
			<share_with_displayname_unique>Tobi Kaminsky</share_with_displayname_unique>
			<status/>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>312</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>31</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1526565018</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note>123123</note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/_act</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>31797</item_source>
			<file_source>31797</file_source>
			<file_parent>103</file_parent>
			<file_target>/_act</file_target>
			<share_with>test@test.de</share_with>
			<share_with_displayname>Tobi</share_with_displayname>
			<share_with_displayname_unique>test@test.de</share_with_displayname_unique>
			<status/>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>313</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1526566821</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/_act/_01.jpg</path>
			<item_type>file</item_type>
			<mimetype>image/jpeg</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>31307</item_source>
			<file_source>31307</file_source>
			<file_parent>31797</file_parent>
			<file_target>/_01.jpg</file_target>
			<share_with>test@test.de</share_with>
			<share_with_displayname>Tobi</share_with_displayname>
			<share_with_displayname_unique>test@test.de</share_with_displayname_unique>
			<status/>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>315</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1526567357</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/_act/_01.jpg</path>
			<item_type>file</item_type>
			<mimetype>image/jpeg</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>31307</item_source>
			<file_source>31307</file_source>
			<file_parent>31797</file_parent>
			<file_target>/_01.jpg</file_target>
			<share_with>tobi2</share_with>
			<share_with_displayname>tobi2</share_with_displayname>
			<share_with_displayname_unique>tobi2</share_with_displayname_unique>
			<status/>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>316</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1526568426</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/_act/_01.jpg</path>
			<item_type>file</item_type>
			<mimetype>image/jpeg</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>31307</item_source>
			<file_source>31307</file_source>
			<file_parent>31797</file_parent>
			<file_target>/_01.jpg</file_target>
			<share_with>tobi@test.de</share_with>
			<share_with_displayname>tobi@test.de</share_with_displayname>
			<share_with_displayname_unique>tobi@test.de</share_with_displayname_unique>
			<status/>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>317</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1526568765</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/_act/_01.jpg</path>
			<item_type>file</item_type>
			<mimetype>image/jpeg</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>31307</item_source>
			<file_source>31307</file_source>
			<file_parent>31797</file_parent>
			<file_target>/_01.jpg</file_target>
			<share_with>tobias@test.de</share_with>
			<share_with_displayname>tobias@test.de</share_with_displayname>
			<share_with_displayname_unique>tobias@test.de</share_with_displayname_unique>
			<status>
				<status>offline</status>
				<message/>
				<icon/>
				<clearAt/>
			</status>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>318</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1526569314</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/_act/_01.jpg</path>
			<item_type>file</item_type>
			<mimetype>image/jpeg</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>31307</item_source>
			<file_source>31307</file_source>
			<file_parent>31797</file_parent>
			<file_target>/_01.jpg</file_target>
			<share_with>admin</share_with>
			<share_with_displayname>Administrator</share_with_displayname>
			<share_with_displayname_unique>admin@next.cloud</share_with_displayname_unique>
			<status>
				<status>dnd</status>
				<message/>
				<icon/>
				<clearAt/>
			</status>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>319</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1526570118</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/_act/_01.jpg</path>
			<item_type>file</item_type>
			<mimetype>image/jpeg</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>31307</item_source>
			<file_source>31307</file_source>
			<file_parent>31797</file_parent>
			<file_target>/_01.jpg</file_target>
			<share_with>Tobi Kaminsky</share_with>
			<share_with_displayname>Tobi Kaminsky</share_with_displayname>
			<share_with_displayname_unique>Tobi Kaminsky</share_with_displayname_unique>
			<status/>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>323</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1527852220</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/_version/123.txt</path>
			<item_type>file</item_type>
			<mimetype>text/plain</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>32849</item_source>
			<file_source>32849</file_source>
			<file_parent>32848</file_parent>
			<file_target>/123.txt</file_target>
			<share_with>admin</share_with>
			<share_with_displayname>Administrator</share_with_displayname>
			<share_with_displayname_unique>admin@next.cloud</share_with_displayname_unique>
			<status>
				<status>dnd</status>
				<message/>
				<icon/>
				<clearAt/>
			</status>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>347</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>31</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1535372378</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/_correctOrder</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>38925</item_source>
			<file_source>38925</file_source>
			<file_parent>103</file_parent>
			<file_target>/_correctOrder</file_target>
			<share_with>admin</share_with>
			<share_with_displayname>Administrator</share_with_displayname>
			<share_with_displayname_unique>admin@next.cloud</share_with_displayname_unique>
			<status>
				<status>dnd</status>
				<message/>
				<icon/>
				<clearAt/>
			</status>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>353</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>31</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1536920479</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/_1/2</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>22993</item_source>
			<file_source>22993</file_source>
			<file_parent>22978</file_parent>
			<file_target>/2 (2)</file_target>
			<share_with>admin</share_with>
			<share_with_displayname>Administrator</share_with_displayname>
			<share_with_displayname_unique>admin@next.cloud</share_with_displayname_unique>
			<status>
				<status>dnd</status>
				<message/>
				<icon/>
				<clearAt/>
			</status>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags>
				<element>_${'$'}!&lt;Favorite&gt;!${'$'}\_</element>
			</tags>
		</element>
		<element>
			<id>354</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>31</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1536921012</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/permission</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>68789</item_source>
			<file_source>68789</file_source>
			<file_parent>103</file_parent>
			<file_target>/1/permission</file_target>
			<share_with>admin</share_with>
			<share_with_displayname>Administrator</share_with_displayname>
			<share_with_displayname_unique>admin@next.cloud</share_with_displayname_unique>
			<status>
				<status>dnd</status>
				<message/>
				<icon/>
				<clearAt/>
			</status>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>356</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>31</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1537730310</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note>hallo</note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/_act</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>31797</item_source>
			<file_source>31797</file_source>
			<file_parent>103</file_parent>
			<file_target>/_act</file_target>
			<share_with>admin</share_with>
			<share_with_displayname>Administrator</share_with_displayname>
			<share_with_displayname_unique>admin@next.cloud</share_with_displayname_unique>
			<status>
				<status>dnd</status>
				<message/>
				<icon/>
				<clearAt/>
			</status>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>361</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>31</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1539064363</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note>Hey Admin</note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/_1/share/shareWithAdmin</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>68954</item_source>
			<file_source>68954</file_source>
			<file_parent>68953</file_parent>
			<file_target>/shareWithAdmin</file_target>
			<share_with>admin</share_with>
			<share_with_displayname>Administrator</share_with_displayname>
			<share_with_displayname_unique>admin@next.cloud</share_with_displayname_unique>
			<status>
				<status>dnd</status>
				<message/>
				<icon/>
				<clearAt/>
			</status>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>373</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>31</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1541417362</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/_1e</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>68756</item_source>
			<file_source>68756</file_source>
			<file_parent>103</file_parent>
			<file_target>/_1e</file_target>
			<share_with>admin</share_with>
			<share_with_displayname>Administrator</share_with_displayname>
			<share_with_displayname_unique>admin@next.cloud</share_with_displayname_unique>
			<status>
				<status>dnd</status>
				<message/>
				<icon/>
				<clearAt/>
			</status>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>375</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>31</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1541417453</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/1</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>760</item_source>
			<file_source>760</file_source>
			<file_parent>103</file_parent>
			<file_target>/1 (2)</file_target>
			<share_with>admin</share_with>
			<share_with_displayname>Administrator</share_with_displayname>
			<share_with_displayname_unique>admin@next.cloud</share_with_displayname_unique>
			<status>
				<status>dnd</status>
				<message/>
				<icon/>
				<clearAt/>
			</status>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>377</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1541504043</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/__hide/123.txt</path>
			<item_type>file</item_type>
			<mimetype>text/plain</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>72092</item_source>
			<file_source>72092</file_source>
			<file_parent>72091</file_parent>
			<file_target>/123 (2).txt</file_target>
			<share_with>admin</share_with>
			<share_with_displayname>Administrator</share_with_displayname>
			<share_with_displayname_unique>admin@next.cloud</share_with_displayname_unique>
			<status>
				<status>dnd</status>
				<message/>
				<icon/>
				<clearAt/>
			</status>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags>
				<element>_${'$'}!&lt;Favorite&gt;!${'$'}\_</element>
			</tags>
		</element>
		<element>
			<id>379</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>31</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1543529702</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/_1</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>22978</item_source>
			<file_source>22978</file_source>
			<file_parent>103</file_parent>
			<file_target>/_1</file_target>
			<share_with>admin</share_with>
			<share_with_displayname>Administrator</share_with_displayname>
			<share_with_displayname_unique>admin@next.cloud</share_with_displayname_unique>
			<status>
				<status>dnd</status>
				<message/>
				<icon/>
				<clearAt/>
			</status>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>380</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1543529762</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/IMG_20160925_124718 (2).jpg</path>
			<item_type>file</item_type>
			<mimetype>image/jpeg</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>983</item_source>
			<file_source>983</file_source>
			<file_parent>103</file_parent>
			<file_target>/IMG_20160925_124718 (2).jpg</file_target>
			<share_with>admin</share_with>
			<share_with_displayname>Administrator</share_with_displayname>
			<share_with_displayname_unique>admin@next.cloud</share_with_displayname_unique>
			<status>
				<status>dnd</status>
				<message/>
				<icon/>
				<clearAt/>
			</status>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>388</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>31</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1547120012</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note>123</note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/__doc</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>73595</item_source>
			<file_source>73595</file_source>
			<file_parent>103</file_parent>
			<file_target>/__doc</file_target>
			<share_with>admin</share_with>
			<share_with_displayname>Administrator</share_with_displayname>
			<share_with_displayname_unique>admin@next.cloud</share_with_displayname_unique>
			<status>
				<status>dnd</status>
				<message/>
				<icon/>
				<clearAt/>
			</status>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>389</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>31</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1547449214</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/_sync</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>39928</item_source>
			<file_source>39928</file_source>
			<file_parent>103</file_parent>
			<file_target>/_sync</file_target>
			<share_with>admin</share_with>
			<share_with_displayname>Administrator</share_with_displayname>
			<share_with_displayname_unique>admin@next.cloud</share_with_displayname_unique>
			<status>
				<status>dnd</status>
				<message/>
				<icon/>
				<clearAt/>
			</status>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>390</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>31</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1547449275</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/sync</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>23880</item_source>
			<file_source>23880</file_source>
			<file_parent>103</file_parent>
			<file_target>/sync</file_target>
			<share_with>admin</share_with>
			<share_with_displayname>Administrator</share_with_displayname>
			<share_with_displayname_unique>admin@next.cloud</share_with_displayname_unique>
			<status>
				<status>dnd</status>
				<message/>
				<icon/>
				<clearAt/>
			</status>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>391</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>31</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1547449433</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/_onlyOneFile</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>23966</item_source>
			<file_source>23966</file_source>
			<file_parent>103</file_parent>
			<file_target>/_onlyOneFile</file_target>
			<share_with>admin</share_with>
			<share_with_displayname>Administrator</share_with_displayname>
			<share_with_displayname_unique>admin@next.cloud</share_with_displayname_unique>
			<status>
				<status>dnd</status>
				<message/>
				<icon/>
				<clearAt/>
			</status>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>408</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1551344681</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/allTypes/share/shared.jpg</path>
			<item_type>file</item_type>
			<mimetype>image/jpeg</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>265</item_source>
			<file_source>265</file_source>
			<file_parent>21376</file_parent>
			<file_target>/shared.jpg</file_target>
			<share_with>Tobi Kaminsky</share_with>
			<share_with_displayname>Tobi Kaminsky</share_with_displayname>
			<share_with_displayname_unique>Tobi Kaminsky</share_with_displayname_unique>
			<status/>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>409</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1551352655</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/allTypes/share/shared.jpg</path>
			<item_type>file</item_type>
			<mimetype>image/jpeg</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>265</item_source>
			<file_source>265</file_source>
			<file_parent>21376</file_parent>
			<file_target>/shared.jpg</file_target>
			<share_with>tobi2</share_with>
			<share_with_displayname>tobi2</share_with_displayname>
			<share_with_displayname_unique>tobi2</share_with_displayname_unique>
			<status/>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>410</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1551358799</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/2018-05-14-092245.png</path>
			<item_type>file</item_type>
			<mimetype>image/png</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>32352</item_source>
			<file_source>32352</file_source>
			<file_parent>103</file_parent>
			<file_target>/2018-05-14-092245.png</file_target>
			<share_with>up</share_with>
			<share_with_displayname>up</share_with_displayname>
			<share_with_displayname_unique>up</share_with_displayname_unique>
			<status/>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>414</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1551952485</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/1_Photos/Squirrel.jpg</path>
			<item_type>file</item_type>
			<mimetype>image/jpeg</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>871</item_source>
			<file_source>871</file_source>
			<file_parent>851</file_parent>
			<file_target>/Squirrel.jpg</file_target>
			<share_with>admin</share_with>
			<share_with_displayname>Administrator</share_with_displayname>
			<share_with_displayname_unique>admin@next.cloud</share_with_displayname_unique>
			<status>
				<status>dnd</status>
				<message/>
				<icon/>
				<clearAt/>
			</status>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>421</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1552896684</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/allTypes/share/shared.jpg</path>
			<item_type>file</item_type>
			<mimetype>image/jpeg</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>265</item_source>
			<file_source>265</file_source>
			<file_parent>21376</file_parent>
			<file_target>/shared.jpg</file_target>
			<share_with>livi</share_with>
			<share_with_displayname>livi</share_with_displayname>
			<share_with_displayname_unique>livi</share_with_displayname_unique>
			<status/>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>428</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>31</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1554369021</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/0</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>759</item_source>
			<file_source>759</file_source>
			<file_parent>103</file_parent>
			<file_target>/0</file_target>
			<share_with>admin</share_with>
			<share_with_displayname>Administrator</share_with_displayname>
			<share_with_displayname_unique>admin@next.cloud</share_with_displayname_unique>
			<status>
				<status>dnd</status>
				<message/>
				<icon/>
				<clearAt/>
			</status>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>469</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1557847405</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/_version/testd.md</path>
			<item_type>file</item_type>
			<mimetype>text/markdown</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>82200</item_source>
			<file_source>82200</file_source>
			<file_parent>32848</file_parent>
			<file_target>/testd.md</file_target>
			<share_with>admin</share_with>
			<share_with_displayname>Administrator</share_with_displayname>
			<share_with_displayname_unique>admin@next.cloud</share_with_displayname_unique>
			<status>
				<status>dnd</status>
				<message/>
				<icon/>
				<clearAt/>
			</status>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>474</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1559649588</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/allTypes/Excel.xlsx</path>
			<item_type>file</item_type>
			<mimetype>application/vnd.openxmlformats-officedocument.spreadsheetml.sheet</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>75723</item_source>
			<file_source>75723</file_source>
			<file_parent>1106</file_parent>
			<file_target>/Excel1.xlsx</file_target>
			<share_with>admin</share_with>
			<share_with_displayname>Administrator</share_with_displayname>
			<share_with_displayname_unique>admin@next.cloud</share_with_displayname_unique>
			<status>
				<status>dnd</status>
				<message/>
				<icon/>
				<clearAt/>
			</status>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>490</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>31</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1561660322</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/_correctOrder</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>38925</item_source>
			<file_source>38925</file_source>
			<file_parent>103</file_parent>
			<file_target>/_correctOrder</file_target>
			<share_with>Tobi Kaminsky</share_with>
			<share_with_displayname>Tobi Kaminsky</share_with_displayname>
			<share_with_displayname_unique>Tobi Kaminsky</share_with_displayname_unique>
			<status/>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>588</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1572618875</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/testForAdmin.md</path>
			<item_type>file</item_type>
			<mimetype>text/markdown</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>89109</item_source>
			<file_source>89109</file_source>
			<file_parent>103</file_parent>
			<file_target>/testForAdmin.md</file_target>
			<share_with>admin</share_with>
			<share_with_displayname>Administrator</share_with_displayname>
			<share_with_displayname_unique>admin@next.cloud</share_with_displayname_unique>
			<status>
				<status>dnd</status>
				<message/>
				<icon/>
				<clearAt/>
			</status>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>638</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1576821627</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/allTypes/testWithLink.md</path>
			<item_type>file</item_type>
			<mimetype>text/markdown</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>93497</item_source>
			<file_source>93497</file_source>
			<file_parent>1106</file_parent>
			<file_target>/testWithLink.md</file_target>
			<share_with>Tobi Kaminsky</share_with>
			<share_with_displayname>Tobi Kaminsky</share_with_displayname>
			<share_with_displayname_unique>Tobi Kaminsky</share_with_displayname_unique>
			<status/>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>641</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1576821887</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/allTypes/testWithLink.md</path>
			<item_type>file</item_type>
			<mimetype>text/markdown</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>93497</item_source>
			<file_source>93497</file_source>
			<file_parent>1106</file_parent>
			<file_target>/testWithLink.md</file_target>
			<share_with>admin</share_with>
			<share_with_displayname>Administrator</share_with_displayname>
			<share_with_displayname_unique>admin@next.cloud</share_with_displayname_unique>
			<status>
				<status>dnd</status>
				<message/>
				<icon/>
				<clearAt/>
			</status>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>644</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1578322313</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/allTypes/README.md</path>
			<item_type>file</item_type>
			<mimetype>text/markdown</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>88729</item_source>
			<file_source>88729</file_source>
			<file_parent>1106</file_parent>
			<file_target>/README.md</file_target>
			<share_with>admin</share_with>
			<share_with_displayname>Administrator</share_with_displayname>
			<share_with_displayname_unique>admin@next.cloud</share_with_displayname_unique>
			<status>
				<status>dnd</status>
				<message/>
				<icon/>
				<clearAt/>
			</status>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>645</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1578322320</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/allTypes/README.md</path>
			<item_type>file</item_type>
			<mimetype>text/markdown</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>88729</item_source>
			<file_source>88729</file_source>
			<file_parent>1106</file_parent>
			<file_target>/README.md</file_target>
			<share_with>test</share_with>
			<share_with_displayname>Test Kaminsky</share_with_displayname>
			<share_with_displayname_unique>new@mail.comtttt</share_with_displayname_unique>
			<status>
				<status>away</status>
				<message/>
				<icon/>
				<clearAt/>
			</status>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>647</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1578322329</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/allTypes/README.md</path>
			<item_type>file</item_type>
			<mimetype>text/markdown</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>88729</item_source>
			<file_source>88729</file_source>
			<file_parent>1106</file_parent>
			<file_target>/README.md</file_target>
			<share_with>test6</share_with>
			<share_with_displayname>test</share_with_displayname>
			<share_with_displayname_unique>test6</share_with_displayname_unique>
			<status/>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>649</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>31</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1578410804</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/_act/3423423</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>93929</item_source>
			<file_source>93929</file_source>
			<file_parent>31797</file_parent>
			<file_target>/3423423</file_target>
			<share_with>admin</share_with>
			<share_with_displayname>Administrator</share_with_displayname>
			<share_with_displayname_unique>admin@next.cloud</share_with_displayname_unique>
			<status>
				<status>dnd</status>
				<message/>
				<icon/>
				<clearAt/>
			</status>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>848</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1586176734</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/allTypes/javaSnippet.md</path>
			<item_type>file</item_type>
			<mimetype>text/markdown</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>88664</item_source>
			<file_source>88664</file_source>
			<file_parent>1106</file_parent>
			<file_target>/javaSnippet.md</file_target>
			<share_with>admin</share_with>
			<share_with_displayname>Administrator</share_with_displayname>
			<share_with_displayname_unique>admin@next.cloud</share_with_displayname_unique>
			<status>
				<status>dnd</status>
				<message/>
				<icon/>
				<clearAt/>
			</status>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags>
				<element>_${'$'}!&lt;Favorite&gt;!${'$'}\_</element>
			</tags>
		</element>
		<element>
			<id>1212</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1592813466</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/allTypes/Lilien-Song mit Bild.mp3</path>
			<item_type>file</item_type>
			<mimetype>audio/mpeg</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>1119</item_source>
			<file_source>1119</file_source>
			<file_parent>1106</file_parent>
			<file_target>/Lilien-Song mit Bild.mp3</file_target>
			<share_with>admin</share_with>
			<share_with_displayname>Administrator</share_with_displayname>
			<share_with_displayname_unique>admin@next.cloud</share_with_displayname_unique>
			<status>
				<status>dnd</status>
				<message/>
				<icon/>
				<clearAt/>
			</status>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags>
				<element>_${'$'}!&lt;Favorite&gt;!${'$'}\_</element>
			</tags>
		</element>
		<element>
			<id>1213</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>17</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1592813894</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/allTypes/image.jpg</path>
			<item_type>file</item_type>
			<mimetype>image/jpeg</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>1125</item_source>
			<file_source>1125</file_source>
			<file_parent>1106</file_parent>
			<file_target>/image.jpg</file_target>
			<share_with>admin</share_with>
			<share_with_displayname>Administrator</share_with_displayname>
			<share_with_displayname_unique>admin@next.cloud</share_with_displayname_unique>
			<status>
				<status>dnd</status>
				<message/>
				<icon/>
				<clearAt/>
			</status>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1249</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1593584101</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note>Admin</note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/all share types</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>131702</item_source>
			<file_source>131702</file_source>
			<file_parent>103</file_parent>
			<file_target>/multiple share links</file_target>
			<share_with>admin</share_with>
			<share_with_displayname>Administrator</share_with_displayname>
			<share_with_displayname_unique>admin@next.cloud</share_with_displayname_unique>
			<status>
				<status>dnd</status>
				<message/>
				<icon/>
				<clearAt/>
			</status>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags>
				<element>_${'$'}!&lt;Favorite&gt;!${'$'}\_</element>
			</tags>
		</element>
		<element>
			<id>1424</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1599114116</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/ShoppingLists/Aldi.lst</path>
			<item_type>file</item_type>
			<mimetype>application/octet-stream</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>124350</item_source>
			<file_source>124350</file_source>
			<file_parent>124344</file_parent>
			<file_target>/Aldi.lst</file_target>
			<share_with>act</share_with>
			<share_with_displayname>act</share_with_displayname>
			<share_with_displayname_unique>act</share_with_displayname_unique>
			<status/>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1433</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1599550302</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/all share types.md</path>
			<item_type>file</item_type>
			<mimetype>text/markdown</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>131782</item_source>
			<file_source>131782</file_source>
			<file_parent>103</file_parent>
			<file_target>/all share types.md</file_target>
			<share_with>admin</share_with>
			<share_with_displayname>Administrator</share_with_displayname>
			<share_with_displayname_unique>admin@next.cloud</share_with_displayname_unique>
			<status>
				<status>dnd</status>
				<message/>
				<icon/>
				<clearAt/>
			</status>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags>
				<element>_${'$'}!&lt;Favorite&gt;!${'$'}\_</element>
			</tags>
		</element>
		<element>
			<id>1497</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>31</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1604923704</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/testIT/1</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>23841</item_source>
			<file_source>23841</file_source>
			<file_parent>23837</file_parent>
			<file_target>/1 (3)</file_target>
			<share_with>admin</share_with>
			<share_with_displayname>Administrator</share_with_displayname>
			<share_with_displayname_unique>admin@next.cloud</share_with_displayname_unique>
			<status>
				<status>dnd</status>
				<message/>
				<icon/>
				<clearAt/>
			</status>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1624</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1614178520</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/InstantUpload/Camera/IMG_20200416_073319.jpg</path>
			<item_type>file</item_type>
			<mimetype>image/jpeg</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>100412</item_source>
			<file_source>100412</file_source>
			<file_parent>100399</file_parent>
			<file_target>/IMG_20200416_073319.jpg</file_target>
			<share_with>admin</share_with>
			<share_with_displayname>Administrator</share_with_displayname>
			<share_with_displayname_unique>admin@next.cloud</share_with_displayname_unique>
			<status>
				<status>dnd</status>
				<message/>
				<icon/>
				<clearAt/>
			</status>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1857</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1624888060</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/.H1</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>150950</item_source>
			<file_source>150950</file_source>
			<file_parent>103</file_parent>
			<file_target>/.H1</file_target>
			<share_with>admin</share_with>
			<share_with_displayname>Administrator</share_with_displayname>
			<share_with_displayname_unique>admin@next.cloud</share_with_displayname_unique>
			<status>
				<status>dnd</status>
				<message/>
				<icon/>
				<clearAt/>
			</status>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1934</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>17</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1625729239</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/all share types/multiple share links.md</path>
			<item_type>file</item_type>
			<mimetype>text/markdown</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>131652</item_source>
			<file_source>131652</file_source>
			<file_parent>131702</file_parent>
			<file_target>/multiple share links.md</file_target>
			<share_with>admin</share_with>
			<share_with_displayname>Administrator</share_with_displayname>
			<share_with_displayname_unique>admin@next.cloud</share_with_displayname_unique>
			<status>
				<status>dnd</status>
				<message/>
				<icon/>
				<clearAt/>
			</status>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags>
				<element>_${'$'}!&lt;Favorite&gt;!${'$'}\_</element>
			</tags>
		</element>
		<element>
			<id>1984</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1626671605</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/InstantUpload/Camera1</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>988</item_source>
			<file_source>988</file_source>
			<file_parent>984</file_parent>
			<file_target>/Camera1</file_target>
			<share_with>admin</share_with>
			<share_with_displayname>Administrator</share_with_displayname>
			<share_with_displayname_unique>admin@next.cloud</share_with_displayname_unique>
			<status>
				<status>dnd</status>
				<message/>
				<icon/>
				<clearAt/>
			</status>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>2305</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1639639780</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/IMG_20210222_154105.jpg</path>
			<item_type>file</item_type>
			<mimetype>image/jpeg</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>148198</item_source>
			<file_source>148198</file_source>
			<file_parent>103</file_parent>
			<file_target>/IMG_20210222_154105.jpg</file_target>
			<share_with>test2</share_with>
			<share_with_displayname>test2</share_with_displayname>
			<share_with_displayname_unique>test2</share_with_displayname_unique>
			<status>
				<status>dnd</status>
				<message/>
				<icon/>
				<clearAt/>
			</status>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>2372</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1647871542</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/2022-01-07_084409.jpg</path>
			<item_type>file</item_type>
			<mimetype>image/jpeg</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>233843</item_source>
			<file_source>233843</file_source>
			<file_parent>103</file_parent>
			<file_target>/2022-01-07_084409.jpg</file_target>
			<share_with>admin</share_with>
			<share_with_displayname>Administrator</share_with_displayname>
			<share_with_displayname_unique>admin@next.cloud</share_with_displayname_unique>
			<status>
				<status>dnd</status>
				<message/>
				<icon/>
				<clearAt/>
			</status>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>2385</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1649063647</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/IMG_20220404_111319.jpg</path>
			<item_type>file</item_type>
			<mimetype>image/jpeg</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>257659</item_source>
			<file_source>257659</file_source>
			<file_parent>103</file_parent>
			<file_target>/IMG_20220404_111319.jpg</file_target>
			<share_with>admin</share_with>
			<share_with_displayname>Administrator</share_with_displayname>
			<share_with_displayname_unique>admin@next.cloud</share_with_displayname_unique>
			<status>
				<status>dnd</status>
				<message/>
				<icon/>
				<clearAt/>
			</status>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>2388</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>5</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1651062317</stime>
			<parent/>
			<expiration>2022-09-24 00:00:00</expiration>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/InstantUpload</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>984</item_source>
			<file_source>984</file_source>
			<file_parent>103</file_parent>
			<file_target>/InstantUpload</file_target>
			<share_with>admin</share_with>
			<share_with_displayname>Administrator</share_with_displayname>
			<share_with_displayname_unique>admin@next.cloud</share_with_displayname_unique>
			<status>
				<status>dnd</status>
				<message/>
				<icon/>
				<clearAt/>
			</status>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags>
				<element>_${'$'}!&lt;Favorite&gt;!${'$'}\_</element>
			</tags>
		</element>
		<element>
			<id>2389</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>31</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1651063003</stime>
			<parent/>
			<expiration>2022-09-24 00:00:00</expiration>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/InstantUpload</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>984</item_source>
			<file_source>984</file_source>
			<file_parent>103</file_parent>
			<file_target>/InstantUpload</file_target>
			<share_with>test6</share_with>
			<share_with_displayname>test</share_with_displayname>
			<share_with_displayname_unique>test6</share_with_displayname_unique>
			<status/>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags>
				<element>_${'$'}!&lt;Favorite&gt;!${'$'}\_</element>
			</tags>
		</element>
		<element>
			<id>2459</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>5</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1652101238</stime>
			<parent/>
			<expiration>2022-10-06 00:00:00</expiration>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/all share types/shared Folder</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>184207</item_source>
			<file_source>184207</file_source>
			<file_parent>131702</file_parent>
			<file_target>/shared Folder</file_target>
			<share_with>admin</share_with>
			<share_with_displayname>Administrator</share_with_displayname>
			<share_with_displayname_unique>admin@next.cloud</share_with_displayname_unique>
			<status>
				<status>dnd</status>
				<message/>
				<icon/>
				<clearAt/>
			</status>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>2507</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1659077541</stime>
			<parent/>
			<expiration>2022-12-26 00:00:00</expiration>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/InstantUpload/IMG_20211116_074501.jpg</path>
			<item_type>file</item_type>
			<mimetype>image/jpeg</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>233625</item_source>
			<file_source>233625</file_source>
			<file_parent>984</file_parent>
			<file_target>/IMG_20211116_074501.jpg</file_target>
			<share_with>test4</share_with>
			<share_with_displayname>test4</share_with_displayname>
			<share_with_displayname_unique>test4</share_with_displayname_unique>
			<status>
				<status>offline</status>
				<message/>
				<icon/>
				<clearAt/>
			</status>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>2509</id>
			<share_type>0</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>3</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1663579276</stime>
			<parent/>
			<expiration>2023-02-16 00:00:00</expiration>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/00/test.ods</path>
			<item_type>file</item_type>
			<mimetype>application/vnd.oasis.opendocument.spreadsheet</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>125783</item_source>
			<file_source>125783</file_source>
			<file_parent>762</file_parent>
			<file_target>/test.ods</file_target>
			<share_with>admin</share_with>
			<share_with_displayname>Administrator</share_with_displayname>
			<share_with_displayname_unique>admin@next.cloud</share_with_displayname_unique>
			<status>
				<status>dnd</status>
				<message/>
				<icon/>
				<clearAt/>
			</status>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags>
				<element>_${'$'}!&lt;Favorite&gt;!${'$'}\_</element>
			</tags>
		</element>
		<element>
			<id>9</id>
			<share_type>1</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>31</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1516958232</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>admin</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Administrator</displayname_file_owner>
			<path>/02</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>shared::/02</storage_id>
			<storage>1</storage>
			<item_source>130</item_source>
			<file_source>130</file_source>
			<file_parent>103</file_parent>
			<file_target>/02</file_target>
			<share_with>admin</share_with>
			<share_with_displayname>admin</share_with_displayname>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>17</id>
			<share_type>1</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>31</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1521189174</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/sync/group</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>23882</item_source>
			<file_source>23882</file_source>
			<file_parent>23880</file_parent>
			<file_target>/1</file_target>
			<share_with>group</share_with>
			<share_with_displayname>group</share_with_displayname>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>19</id>
			<share_type>1</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>31</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1521193188</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/sync/LinkUserGroup</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>23962</item_source>
			<file_source>23962</file_source>
			<file_parent>23880</file_parent>
			<file_target>/LinkUserGroup</file_target>
			<share_with>group</share_with>
			<share_with_displayname>group</share_with_displayname>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>468</id>
			<share_type>1</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1557847128</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/123123.txt</path>
			<item_type>file</item_type>
			<mimetype>text/plain</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>81104</item_source>
			<file_source>81104</file_source>
			<file_parent>103</file_parent>
			<file_target>/123123.txt</file_target>
			<share_with>admin</share_with>
			<share_with_displayname>admin</share_with_displayname>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1255</id>
			<share_type>1</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>31</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1593685628</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/allTypes/share/shareToGroup</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>131754</item_source>
			<file_source>131754</file_source>
			<file_parent>21376</file_parent>
			<file_target>/shareToGroup</file_target>
			<share_with>group</share_with>
			<share_with_displayname>group</share_with_displayname>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1264</id>
			<share_type>1</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>31</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1594036309</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/all share types</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>131702</item_source>
			<file_source>131702</file_source>
			<file_parent>103</file_parent>
			<file_target>/all share types</file_target>
			<share_with>group</share_with>
			<share_with_displayname>group</share_with_displayname>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags>
				<element>_${'$'}!&lt;Favorite&gt;!$\_</element>
			</tags>
		</element>
		<element>
			<id>1430</id>
			<share_type>1</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1599550296</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/all share types.md</path>
			<item_type>file</item_type>
			<mimetype>text/markdown</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>131782</item_source>
			<file_source>131782</file_source>
			<file_parent>103</file_parent>
			<file_target>/all share types.md</file_target>
			<share_with>group</share_with>
			<share_with_displayname>group</share_with_displayname>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags>
				<element>_${'$'}!&lt;Favorite&gt;!$\_</element>
			</tags>
		</element>
		<element>
			<id>1529</id>
			<share_type>1</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>27</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1609928525</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Old</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>131772</item_source>
			<file_source>131772</file_source>
			<file_parent>103</file_parent>
			<file_target>/Old</file_target>
			<share_with>admin</share_with>
			<share_with_displayname>admin</share_with_displayname>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>15</id>
			<share_type>3</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1521185813</stime>
			<parent/>
			<expiration/>
			<token>9DRw6EHsJx6oCc6</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/sync/link.txt</path>
			<item_type>file</item_type>
			<mimetype>text/plain</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>23884</item_source>
			<file_source>23884</file_source>
			<file_parent>23880</file_parent>
			<file_target>/123.txt</file_target>
			<share_with/>
			<share_with_displayname>(Shared link)</share_with_displayname>
			<password/>
			<send_password_by_talk></send_password_by_talk>
			<url>http://localhost/nc/index.php/s/9DRw6EHsJx6oCc6</url>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>20</id>
			<share_type>3</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1521193189</stime>
			<parent/>
			<expiration/>
			<token>rbafbtxACG7c3GY</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/sync/LinkUserGroup</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>23962</item_source>
			<file_source>23962</file_source>
			<file_parent>23880</file_parent>
			<file_target>/LinkUserGroup</file_target>
			<share_with/>
			<share_with_displayname>(Shared link)</share_with_displayname>
			<password/>
			<send_password_by_talk></send_password_by_talk>
			<url>http://localhost/nc/index.php/s/rbafbtxACG7c3GY</url>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>21</id>
			<share_type>3</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1521197421</stime>
			<parent/>
			<expiration/>
			<token>rweToTs4KGwJQX5</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/sync/New folder</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>23963</item_source>
			<file_source>23963</file_source>
			<file_parent>23880</file_parent>
			<file_target>/New folder</file_target>
			<share_with/>
			<share_with_displayname>(Shared link)</share_with_displayname>
			<password/>
			<send_password_by_talk></send_password_by_talk>
			<url>http://localhost/nc/index.php/s/rweToTs4KGwJQX5</url>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>307</id>
			<share_type>3</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1526310624</stime>
			<parent/>
			<expiration/>
			<token>XQ4xYgwiXcGwsxA</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/_act/test.txt</path>
			<item_type>file</item_type>
			<mimetype>text/plain</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>32368</item_source>
			<file_source>32368</file_source>
			<file_parent>31797</file_parent>
			<file_target>/test.txt</file_target>
			<share_with/>
			<share_with_displayname>(Shared link)</share_with_displayname>
			<password/>
			<send_password_by_talk></send_password_by_talk>
			<url>http://localhost/nc/index.php/s/XQ4xYgwiXcGwsxA</url>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>320</id>
			<share_type>3</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1527110048</stime>
			<parent/>
			<expiration/>
			<token>ikNLa2zsY58iDsB</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Events/Hackweek</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>33075</item_source>
			<file_source>33075</file_source>
			<file_parent>33074</file_parent>
			<file_target>/Hackweek</file_target>
			<share_with/>
			<share_with_displayname>(Shared link)</share_with_displayname>
			<password/>
			<send_password_by_talk></send_password_by_talk>
			<url>http://localhost/nc/index.php/s/ikNLa2zsY58iDsB</url>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>321</id>
			<share_type>3</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1527110156</stime>
			<parent/>
			<expiration/>
			<token>gtB8Md77MzSfZQN</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Events/Hackweek</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>33075</item_source>
			<file_source>33075</file_source>
			<file_parent>33074</file_parent>
			<file_target>/Hackweek</file_target>
			<share_with/>
			<share_with_displayname>(Shared link)</share_with_displayname>
			<password/>
			<send_password_by_talk></send_password_by_talk>
			<url>http://localhost/nc/index.php/s/gtB8Md77MzSfZQN</url>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>322</id>
			<share_type>3</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>5</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1527111327</stime>
			<parent/>
			<expiration/>
			<token>BkCxGBH9ayeRRAQ</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Events/Hackweek/tobi</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>33133</item_source>
			<file_source>33133</file_source>
			<file_parent>33075</file_parent>
			<file_target>/tobi</file_target>
			<share_with/>
			<share_with_displayname>(Shared link)</share_with_displayname>
			<password/>
			<send_password_by_talk></send_password_by_talk>
			<url>http://localhost/nc/index.php/s/BkCxGBH9ayeRRAQ</url>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>326</id>
			<share_type>3</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1528984802</stime>
			<parent/>
			<expiration/>
			<token>Ec8d4LyojypQtii</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/sync</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>23880</item_source>
			<file_source>23880</file_source>
			<file_parent>103</file_parent>
			<file_target>/sync</file_target>
			<share_with/>
			<share_with_displayname>(Shared link)</share_with_displayname>
			<password/>
			<send_password_by_talk></send_password_by_talk>
			<url>http://localhost/nc/index.php/s/Ec8d4LyojypQtii</url>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>329</id>
			<share_type>3</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1529651524</stime>
			<parent/>
			<expiration/>
			<token>bqoQ5xwkmo2TFAT</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/_version/123.txt</path>
			<item_type>file</item_type>
			<mimetype>text/plain</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>32849</item_source>
			<file_source>32849</file_source>
			<file_parent>32848</file_parent>
			<file_target>/123.txt</file_target>
			<share_with/>
			<share_with_displayname>(Shared link)</share_with_displayname>
			<password/>
			<send_password_by_talk></send_password_by_talk>
			<url>http://localhost/nc/index.php/s/bqoQ5xwkmo2TFAT</url>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>332</id>
			<share_type>3</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1530522050</stime>
			<parent/>
			<expiration/>
			<token>RCSdrGm3dcE483Z</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/_hidden/51th.jpg</path>
			<item_type>file</item_type>
			<mimetype>image/jpeg</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>36477</item_source>
			<file_source>36477</file_source>
			<file_parent>36473</file_parent>
			<file_target>/5th.jpg</file_target>
			<share_with/>
			<share_with_displayname>(Shared link)</share_with_displayname>
			<password/>
			<send_password_by_talk></send_password_by_talk>
			<url>http://localhost/nc/index.php/s/RCSdrGm3dcE483Z</url>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>334</id>
			<share_type>3</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1530522682</stime>
			<parent/>
			<expiration/>
			<token>8M9LTxTLyjD7e3z</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/_hidden/6th.jpg</path>
			<item_type>file</item_type>
			<mimetype>image/jpeg</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>36474</item_source>
			<file_source>36474</file_source>
			<file_parent>36473</file_parent>
			<file_target>/6th.jpg</file_target>
			<share_with/>
			<share_with_displayname>(Shared link)</share_with_displayname>
			<password/>
			<send_password_by_talk></send_password_by_talk>
			<url>http://localhost/nc/index.php/s/8M9LTxTLyjD7e3z</url>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>349</id>
			<share_type>3</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1535983897</stime>
			<parent/>
			<expiration/>
			<token>67ZXSW5q4nSSpEk</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/_hidden</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>36473</item_source>
			<file_source>36473</file_source>
			<file_parent>103</file_parent>
			<file_target>/_hidden</file_target>
			<share_with/>
			<share_with_displayname>(Shared link)</share_with_displayname>
			<password/>
			<send_password_by_talk></send_password_by_talk>
			<url>http://localhost/nc/index.php/s/67ZXSW5q4nSSpEk</url>
			<mail_send>0</mail_send>
			<hide_download>1</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>350</id>
			<share_type>3</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1536051798</stime>
			<parent/>
			<expiration/>
			<token>XXbcSNCG77cWwS4</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/_caching/1.jpg</path>
			<item_type>file</item_type>
			<mimetype>image/jpeg</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>39121</item_source>
			<file_source>39121</file_source>
			<file_parent>39120</file_parent>
			<file_target>/1.jpg</file_target>
			<share_with/>
			<share_with_displayname>(Shared link)</share_with_displayname>
			<password/>
			<send_password_by_talk></send_password_by_talk>
			<url>http://localhost/nc/index.php/s/XXbcSNCG77cWwS4</url>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>363</id>
			<share_type>3</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1539340493</stime>
			<parent/>
			<expiration/>
			<token>3toPrdKP7HTj4MT</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/_1e</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>68756</item_source>
			<file_source>68756</file_source>
			<file_parent>103</file_parent>
			<file_target>/_1e</file_target>
			<share_with>2|aMo7p+3b+QPHe1o</share_with>
			<share_with_displayname>(Shared link)</share_with_displayname>
			<password>21o</password>
			<send_password_by_talk></send_password_by_talk>
			<url>http://localhost/nc/index.php/s/3toPrdKP7HTj4MT</url>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>365</id>
			<share_type>3</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1540906344</stime>
			<parent/>
			<expiration/>
			<token>B8gwNdwiz3Zs9SE</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/_caching</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>39120</item_source>
			<file_source>39120</file_source>
			<file_parent>103</file_parent>
			<file_target>/_caching</file_target>
			<share_with/>
			<share_with_displayname>(Shared link)</share_with_displayname>
			<password/>
			<send_password_by_talk></send_password_by_talk>
			<url>http://localhost/nc/index.php/s/B8gwNdwiz3Zs9SE</url>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>366</id>
			<share_type>3</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1540906884</stime>
			<parent/>
			<expiration/>
			<token>m8H6LDpajZDDAYY</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/04.gif</path>
			<item_type>file</item_type>
			<mimetype>image/gif</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>71907</item_source>
			<file_source>71907</file_source>
			<file_parent>103</file_parent>
			<file_target>/04.gif</file_target>
			<share_with/>
			<share_with_displayname>(Shared link)</share_with_displayname>
			<password/>
			<send_password_by_talk></send_password_by_talk>
			<url>http://localhost/nc/index.php/s/m8H6LDpajZDDAYY</url>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>374</id>
			<share_type>3</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1541417403</stime>
			<parent/>
			<expiration/>
			<token>JNtQsBSoBFPc7ib</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/_act</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>31797</item_source>
			<file_source>31797</file_source>
			<file_parent>103</file_parent>
			<file_target>/_act</file_target>
			<share_with/>
			<share_with_displayname>(Shared link)</share_with_displayname>
			<password/>
			<send_password_by_talk></send_password_by_talk>
			<url>http://localhost/nc/index.php/s/JNtQsBSoBFPc7ib</url>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>395</id>
			<share_type>3</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1549369203</stime>
			<parent/>
			<expiration/>
			<token>brriEA8cxPkP8xR</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/allTypes/image.jpg</path>
			<item_type>file</item_type>
			<mimetype>image/jpeg</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>1125</item_source>
			<file_source>1125</file_source>
			<file_parent>1106</file_parent>
			<file_target>/image.jpg</file_target>
			<share_with/>
			<share_with_displayname>(Shared link)</share_with_displayname>
			<password/>
			<send_password_by_talk></send_password_by_talk>
			<url>http://localhost/nc/index.php/s/brriEA8cxPkP8xR</url>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>396</id>
			<share_type>3</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>17</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1549370359</stime>
			<parent/>
			<expiration/>
			<token>saTLndBfSD3XG5R</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/allTypes/video.mp4</path>
			<item_type>file</item_type>
			<mimetype>video/mp4</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>1135</item_source>
			<file_source>1135</file_source>
			<file_parent>1106</file_parent>
			<file_target>/video.mp4</file_target>
			<share_with>3|pre5KyE</share_with>
			<share_with_displayname>(Shared link)</share_with_displayname>
			<password>3DfNUqHsJpaNpre5KyE</password>
			<send_password_by_talk></send_password_by_talk>
			<url>http://localhost/nc/index.php/s/saTLndBfSD3XG5R</url>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags>
				<element>_${'$'}!&lt;Favorite&gt;!$\_</element>
			</tags>
		</element>
		<element>
			<id>398</id>
			<share_type>3</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>15</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1549372346</stime>
			<parent/>
			<expiration/>
			<token>9ZPrkfWHPmti9Ck</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/_1e/1</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>68757</item_source>
			<file_source>68757</file_source>
			<file_parent>68756</file_parent>
			<file_target>/1</file_target>
			<share_with/>
			<share_with_displayname>(Shared link)</share_with_displayname>
			<password/>
			<send_password_by_talk></send_password_by_talk>
			<url>http://localhost/nc/index.php/s/9ZPrkfWHPmti9Ck</url>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>400</id>
			<share_type>3</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1549436155</stime>
			<parent/>
			<expiration/>
			<token>jYLF5YWeKYjCtfg</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/_1/size/123 123.vcf</path>
			<item_type>file</item_type>
			<mimetype>text/vcard</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>75683</item_source>
			<file_source>75683</file_source>
			<file_parent>68807</file_parent>
			<file_target>/123 123.vcf</file_target>
			<share_with/>
			<share_with_displayname>(Shared link)</share_with_displayname>
			<password/>
			<send_password_by_talk></send_password_by_talk>
			<url>http://localhost/nc/index.php/s/jYLF5YWeKYjCtfg</url>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>417</id>
			<share_type>3</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1552304295</stime>
			<parent/>
			<expiration/>
			<token>gqqYGA37jpSPc5E</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/newImages</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>75512</item_source>
			<file_source>75512</file_source>
			<file_parent>103</file_parent>
			<file_target>/newImages</file_target>
			<share_with/>
			<share_with_displayname>(Shared link)</share_with_displayname>
			<password/>
			<send_password_by_talk></send_password_by_talk>
			<url>http://localhost/nc/index.php/s/gqqYGA37jpSPc5E</url>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>418</id>
			<share_type>3</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1552304303</stime>
			<parent/>
			<expiration/>
			<token>X4WALYEXMryaSyA</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/newImages</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>75512</item_source>
			<file_source>75512</file_source>
			<file_parent>103</file_parent>
			<file_target>/newImages</file_target>
			<share_with/>
			<share_with_displayname>(Shared link)</share_with_displayname>
			<password/>
			<send_password_by_talk></send_password_by_talk>
			<url>http://localhost/nc/index.php/s/X4WALYEXMryaSyA</url>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>419</id>
			<share_type>3</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1552494062</stime>
			<parent/>
			<expiration/>
			<token>KxZy6xY78ezF8sA</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/_caching</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>39120</item_source>
			<file_source>39120</file_source>
			<file_parent>103</file_parent>
			<file_target>/_caching</file_target>
			<share_with/>
			<share_with_displayname>(Shared link)</share_with_displayname>
			<password/>
			<send_password_by_talk></send_password_by_talk>
			<url>http://localhost/nc/index.php/s/KxZy6xY78ezF8sA</url>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>427</id>
			<share_type>3</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1554368995</stime>
			<parent/>
			<expiration/>
			<token>WGMDnHKXPFaX6L8</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/0</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>759</item_source>
			<file_source>759</file_source>
			<file_parent>103</file_parent>
			<file_target>/0</file_target>
			<share_with/>
			<share_with_displayname>(Shared link)</share_with_displayname>
			<password/>
			<send_password_by_talk></send_password_by_talk>
			<url>http://localhost/nc/index.php/s/WGMDnHKXPFaX6L8</url>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>444</id>
			<share_type>3</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1556601676</stime>
			<parent/>
			<expiration/>
			<token>DaHoMFx5J44oQeE</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Android/Tobi-Android-stable-3.6.0-build-16-signed.apk</path>
			<item_type>file</item_type>
			<mimetype>application/vnd.android.package-archive</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>81327</item_source>
			<file_source>81327</file_source>
			<file_parent>81321</file_parent>
			<file_target>/Tobi-Android-stable-3.6.0-build-16-signed.apk</file_target>
			<share_with/>
			<share_with_displayname>(Shared link)</share_with_displayname>
			<password/>
			<send_password_by_talk></send_password_by_talk>
			<url>http://localhost/nc/index.php/s/DaHoMFx5J44oQeE</url>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>445</id>
			<share_type>3</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1556602584</stime>
			<parent/>
			<expiration/>
			<token>XS5aTL8KkJB7tMA</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Android/Tobi-Android-stable-3.5.0-build-20-signed.apk</path>
			<item_type>file</item_type>
			<mimetype>application/vnd.android.package-archive</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>81334</item_source>
			<file_source>81334</file_source>
			<file_parent>81321</file_parent>
			<file_target>/Tobi-Android-stable-3.5.0-build-20-signed.apk</file_target>
			<share_with/>
			<share_with_displayname>(Shared link)</share_with_displayname>
			<password/>
			<send_password_by_talk></send_password_by_talk>
			<url>http://localhost/nc/index.php/s/XS5aTL8KkJB7tMA</url>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>446</id>
			<share_type>3</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1556602726</stime>
			<parent/>
			<expiration/>
			<token>ytk3j6RWGsye9cN</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Android/Tobi-Android-stable-3.5.1-build-21-signed.apk</path>
			<item_type>file</item_type>
			<mimetype>application/vnd.android.package-archive</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>81335</item_source>
			<file_source>81335</file_source>
			<file_parent>81321</file_parent>
			<file_target>/Tobi-Android-stable-3.5.1-build-21-signed.apk</file_target>
			<share_with/>
			<share_with_displayname>(Shared link)</share_with_displayname>
			<password/>
			<send_password_by_talk></send_password_by_talk>
			<url>http://localhost/nc/index.php/s/ytk3j6RWGsye9cN</url>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>447</id>
			<share_type>3</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1556631199</stime>
			<parent/>
			<expiration/>
			<token>K7WF8Wy3rJtaoZ2</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/__doc</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>73595</item_source>
			<file_source>73595</file_source>
			<file_parent>103</file_parent>
			<file_target>/__doc</file_target>
			<share_with/>
			<share_with_displayname>(Shared link)</share_with_displayname>
			<password/>
			<send_password_by_talk></send_password_by_talk>
			<url>http://localhost/nc/index.php/s/K7WF8Wy3rJtaoZ2</url>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>470</id>
			<share_type>3</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1558355096</stime>
			<parent/>
			<expiration/>
			<token>g6JH5TomTgQboE2</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/2waySync</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>79366</item_source>
			<file_source>79366</file_source>
			<file_parent>103</file_parent>
			<file_target>/2waySync</file_target>
			<share_with/>
			<share_with_displayname>(Shared link)</share_with_displayname>
			<password/>
			<send_password_by_talk></send_password_by_talk>
			<url>http://localhost/nc/index.php/s/g6JH5TomTgQboE2</url>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>471</id>
			<share_type>3</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1559558281</stime>
			<parent/>
			<expiration/>
			<token>Ae2jrSEJ8Ai2WMH</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Android/Tobi-Android-master-build-24-signed.apk</path>
			<item_type>file</item_type>
			<mimetype>application/vnd.android.package-archive</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>82349</item_source>
			<file_source>82349</file_source>
			<file_parent>81321</file_parent>
			<file_target>/Tobi-Android-master-build-24-signed.apk</file_target>
			<share_with/>
			<share_with_displayname>(Shared link)</share_with_displayname>
			<password/>
			<send_password_by_talk></send_password_by_talk>
			<url>http://localhost/nc/index.php/s/Ae2jrSEJ8Ai2WMH</url>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>472</id>
			<share_type>3</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1559633184</stime>
			<parent/>
			<expiration/>
			<token>CZysKscjaMTgryM</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Android/Tobi-Android-stable-3.6.1-build-25-signed.apk</path>
			<item_type>file</item_type>
			<mimetype>application/vnd.android.package-archive</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>82525</item_source>
			<file_source>82525</file_source>
			<file_parent>81321</file_parent>
			<file_target>/Tobi-Android-stable-3.6.1-build-25-signed.apk</file_target>
			<share_with/>
			<share_with_displayname>(Shared link)</share_with_displayname>
			<password/>
			<send_password_by_talk></send_password_by_talk>
			<url>http://localhost/nc/index.php/s/CZysKscjaMTgryM</url>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>473</id>
			<share_type>3</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1559633455</stime>
			<parent/>
			<expiration/>
			<token>rHXZYxz69G6XWxM</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Android/Tobi-Android-stable-3.6.2-build-26-signed.apk</path>
			<item_type>file</item_type>
			<mimetype>application/vnd.android.package-archive</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>82526</item_source>
			<file_source>82526</file_source>
			<file_parent>81321</file_parent>
			<file_target>/Tobi-Android-stable-3.6.2-build-26-signed.apk</file_target>
			<share_with/>
			<share_with_displayname>(Shared link)</share_with_displayname>
			<password/>
			<send_password_by_talk></send_password_by_talk>
			<url>http://localhost/nc/index.php/s/rHXZYxz69G6XWxM</url>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>475</id>
			<share_type>3</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1559651696</stime>
			<parent/>
			<expiration/>
			<token>ey9YaMGiGftwaCq</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/allTypes/Excel.xlsx</path>
			<item_type>file</item_type>
			<mimetype>application/vnd.openxmlformats-officedocument.spreadsheetml.sheet</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>75723</item_source>
			<file_source>75723</file_source>
			<file_parent>1106</file_parent>
			<file_target>/Excel.xlsx</file_target>
			<share_with/>
			<share_with_displayname>(Shared link)</share_with_displayname>
			<password/>
			<send_password_by_talk></send_password_by_talk>
			<url>http://localhost/nc/index.php/s/ey9YaMGiGftwaCq</url>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>476</id>
			<share_type>3</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1559663467</stime>
			<parent/>
			<expiration/>
			<token>CccxttMC8XY6jCJ</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Linux/Drive Merkur.works-Linux64-2.5.3-rc1-build-28.AppImage</path>
			<item_type>file</item_type>
			<mimetype>application/octet-stream</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>82686</item_source>
			<file_source>82686</file_source>
			<file_parent>82685</file_parent>
			<file_target>/Drive Merkur.works-Linux64-2.5.3-rc1-build-28.AppImage</file_target>
			<share_with/>
			<share_with_displayname>(Shared link)</share_with_displayname>
			<password/>
			<send_password_by_talk></send_password_by_talk>
			<url>http://localhost/nc/index.php/s/CccxttMC8XY6jCJ</url>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>477</id>
			<share_type>3</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1559807908</stime>
			<parent/>
			<expiration/>
			<token>mGDeEwyHBCztwtb</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Linux/Drive Merkur.works-Linux64-2.5.3-rc1-build-32.AppImage</path>
			<item_type>file</item_type>
			<mimetype>application/octet-stream</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>82750</item_source>
			<file_source>82750</file_source>
			<file_parent>82685</file_parent>
			<file_target>/Drive Merkur.works-Linux64-2.5.3-rc1-build-32.AppImage</file_target>
			<share_with/>
			<share_with_displayname>(Shared link)</share_with_displayname>
			<password/>
			<send_password_by_talk></send_password_by_talk>
			<url>http://localhost/nc/index.php/s/mGDeEwyHBCztwtb</url>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>478</id>
			<share_type>3</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1559810491</stime>
			<parent/>
			<expiration/>
			<token>5G5osBjzW4fkKRJ</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Linux/Drive Merkur.works-Linux64-2.5.3-rc1-build-33.AppImage</path>
			<item_type>file</item_type>
			<mimetype>application/octet-stream</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>82754</item_source>
			<file_source>82754</file_source>
			<file_parent>82685</file_parent>
			<file_target>/Drive Merkur.works-Linux64-2.5.3-rc1-build-33.AppImage</file_target>
			<share_with/>
			<share_with_displayname>(Shared link)</share_with_displayname>
			<password/>
			<send_password_by_talk></send_password_by_talk>
			<url>http://localhost/nc/index.php/s/5G5osBjzW4fkKRJ</url>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>479</id>
			<share_type>3</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1559887963</stime>
			<parent/>
			<expiration/>
			<token>Azn9Z5zj6y7YFNt</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Linux/Drive Merkur.works-Linux64-2.5.2-build-35.AppImage</path>
			<item_type>file</item_type>
			<mimetype>application/octet-stream</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>82779</item_source>
			<file_source>82779</file_source>
			<file_parent>82685</file_parent>
			<file_target>/Drive Merkur.works-Linux64-2.5.2-build-35.AppImage</file_target>
			<share_with/>
			<share_with_displayname>(Shared link)</share_with_displayname>
			<password/>
			<send_password_by_talk></send_password_by_talk>
			<url>http://localhost/nc/index.php/s/Azn9Z5zj6y7YFNt</url>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>480</id>
			<share_type>3</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1559903495</stime>
			<parent/>
			<expiration/>
			<token>oEY98fB2YiJw864</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Android/Tobi-Android-stable-3.6.2-build-37-signed.apk</path>
			<item_type>file</item_type>
			<mimetype>application/vnd.android.package-archive</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>82809</item_source>
			<file_source>82809</file_source>
			<file_parent>81321</file_parent>
			<file_target>/Tobi-Android-stable-3.6.2-build-37-signed.apk</file_target>
			<share_with/>
			<share_with_displayname>(Shared link)</share_with_displayname>
			<password/>
			<send_password_by_talk></send_password_by_talk>
			<url>http://localhost/nc/index.php/s/oEY98fB2YiJw864</url>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>481</id>
			<share_type>3</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1559903743</stime>
			<parent/>
			<expiration/>
			<token>A9EMfXC5gcsDBof</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Android/Tobi-Android-master-build-38-signed.apk</path>
			<item_type>file</item_type>
			<mimetype>application/vnd.android.package-archive</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>82813</item_source>
			<file_source>82813</file_source>
			<file_parent>81321</file_parent>
			<file_target>/Tobi-Android-master-build-38-signed.apk</file_target>
			<share_with/>
			<share_with_displayname>(Shared link)</share_with_displayname>
			<password/>
			<send_password_by_talk></send_password_by_talk>
			<url>http://localhost/nc/index.php/s/A9EMfXC5gcsDBof</url>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>482</id>
			<share_type>3</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1560243578</stime>
			<parent/>
			<expiration/>
			<token>eYBcKtADrsmmmSz</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Android/Tobi-Android-stable-3.6.2-build-40-signed.apk</path>
			<item_type>file</item_type>
			<mimetype>application/vnd.android.package-archive</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>82814</item_source>
			<file_source>82814</file_source>
			<file_parent>81321</file_parent>
			<file_target>/Tobi-Android-stable-3.6.2-build-40-signed.apk</file_target>
			<share_with/>
			<share_with_displayname>(Shared link)</share_with_displayname>
			<password/>
			<send_password_by_talk></send_password_by_talk>
			<url>http://localhost/nc/index.php/s/eYBcKtADrsmmmSz</url>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>483</id>
			<share_type>3</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1560264092</stime>
			<parent/>
			<expiration/>
			<token>d9r6wNktxwmrzXR</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Linux/Example-Linux64-2.5.3-rc1-build-41.AppImage</path>
			<item_type>file</item_type>
			<mimetype>application/octet-stream</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>82815</item_source>
			<file_source>82815</file_source>
			<file_parent>82685</file_parent>
			<file_target>/Example-Linux64-2.5.3-rc1-build-41.AppImage</file_target>
			<share_with/>
			<share_with_displayname>(Shared link)</share_with_displayname>
			<password/>
			<send_password_by_talk></send_password_by_talk>
			<url>http://localhost/nc/index.php/s/d9r6wNktxwmrzXR</url>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>484</id>
			<share_type>3</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1560327217</stime>
			<parent/>
			<expiration/>
			<token>jw7SBfnrCscLYKD</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Android/Tobi-Android-stable-3.6.2-build-45-signed.apk</path>
			<item_type>file</item_type>
			<mimetype>application/vnd.android.package-archive</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>82836</item_source>
			<file_source>82836</file_source>
			<file_parent>81321</file_parent>
			<file_target>/Tobi-Android-stable-3.6.2-build-45-signed.apk</file_target>
			<share_with/>
			<share_with_displayname>(Shared link)</share_with_displayname>
			<password/>
			<send_password_by_talk></send_password_by_talk>
			<url>http://localhost/nc/index.php/s/jw7SBfnrCscLYKD</url>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>485</id>
			<share_type>3</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1560327448</stime>
			<parent/>
			<expiration/>
			<token>46PrxCJc5mA65rs</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Android/Tobi-Android-master-build-46-signed.apk</path>
			<item_type>file</item_type>
			<mimetype>application/vnd.android.package-archive</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>82837</item_source>
			<file_source>82837</file_source>
			<file_parent>81321</file_parent>
			<file_target>/Tobi-Android-master-build-46-signed.apk</file_target>
			<share_with/>
			<share_with_displayname>(Shared link)</share_with_displayname>
			<password/>
			<send_password_by_talk></send_password_by_talk>
			<url>http://localhost/nc/index.php/s/46PrxCJc5mA65rs</url>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>486</id>
			<share_type>3</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1560328037</stime>
			<parent/>
			<expiration/>
			<token>Roxf3bLpHGBcFD2</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Android/Tobi-Android-master-build-47-signed.apk</path>
			<item_type>file</item_type>
			<mimetype>application/vnd.android.package-archive</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>82838</item_source>
			<file_source>82838</file_source>
			<file_parent>81321</file_parent>
			<file_target>/Tobi-Android-master-build-47-signed.apk</file_target>
			<share_with/>
			<share_with_displayname>(Shared link)</share_with_displayname>
			<password/>
			<send_password_by_talk></send_password_by_talk>
			<url>http://localhost/nc/index.php/s/Roxf3bLpHGBcFD2</url>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>487</id>
			<share_type>3</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1560328433</stime>
			<parent/>
			<expiration/>
			<token>yLw6LD6PPaLaATD</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Android/Tobi-Android-master-build-48-signed.apk</path>
			<item_type>file</item_type>
			<mimetype>application/vnd.android.package-archive</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>82839</item_source>
			<file_source>82839</file_source>
			<file_parent>81321</file_parent>
			<file_target>/Tobi-Android-master-build-48-signed.apk</file_target>
			<share_with/>
			<share_with_displayname>(Shared link)</share_with_displayname>
			<password/>
			<send_password_by_talk></send_password_by_talk>
			<url>http://localhost/nc/index.php/s/yLw6LD6PPaLaATD</url>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>488</id>
			<share_type>3</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1560328740</stime>
			<parent/>
			<expiration/>
			<token>mM95XTtBfxXFJoB</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Android/Tobi-Android-master-build-49-signed.apk</path>
			<item_type>file</item_type>
			<mimetype>application/vnd.android.package-archive</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>82840</item_source>
			<file_source>82840</file_source>
			<file_parent>81321</file_parent>
			<file_target>/Tobi-Android-master-build-49-signed.apk</file_target>
			<share_with/>
			<share_with_displayname>(Shared link)</share_with_displayname>
			<password/>
			<send_password_by_talk></send_password_by_talk>
			<url>http://localhost/nc/index.php/s/mM95XTtBfxXFJoB</url>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>489</id>
			<share_type>3</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1561650748</stime>
			<parent/>
			<expiration/>
			<token>2JgXmnE7Ptr5Fmq</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Android/Example-Android-stable-3.6.2-build-65-signed.apk</path>
			<item_type>file</item_type>
			<mimetype>application/vnd.android.package-archive</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>83060</item_source>
			<file_source>83060</file_source>
			<file_parent>81321</file_parent>
			<file_target>/Example-Android-stable-3.6.2-build-65-signed.apk</file_target>
			<share_with/>
			<share_with_displayname>(Shared link)</share_with_displayname>
			<password/>
			<send_password_by_talk></send_password_by_talk>
			<url>http://localhost/nc/index.php/s/2JgXmnE7Ptr5Fmq</url>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>491</id>
			<share_type>3</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1561660326</stime>
			<parent/>
			<expiration/>
			<token>BQtANr4TpZz8ZpD</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/_correctOrder</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>38925</item_source>
			<file_source>38925</file_source>
			<file_parent>103</file_parent>
			<file_target>/_correctOrder</file_target>
			<share_with/>
			<share_with_displayname>(Shared link)</share_with_displayname>
			<password/>
			<send_password_by_talk></send_password_by_talk>
			<url>http://localhost/nc/index.php/s/BQtANr4TpZz8ZpD</url>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>492</id>
			<share_type>3</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1561967982</stime>
			<parent/>
			<expiration/>
			<token>w7qkynBTgapxs4x</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Linux/Tobi-Linux64-2.5.3-rc2-build-66.AppImage</path>
			<item_type>file</item_type>
			<mimetype>application/octet-stream</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>83070</item_source>
			<file_source>83070</file_source>
			<file_parent>82685</file_parent>
			<file_target>/Tobi-Linux64-2.5.3-rc2-build-66.AppImage</file_target>
			<share_with/>
			<share_with_displayname>(Shared link)</share_with_displayname>
			<password/>
			<send_password_by_talk></send_password_by_talk>
			<url>http://localhost/nc/index.php/s/w7qkynBTgapxs4x</url>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>493</id>
			<share_type>3</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1562141754</stime>
			<parent/>
			<expiration/>
			<token>nALkbcS96tFmb5J</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/allTypes/Empty</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>1109</item_source>
			<file_source>1109</file_source>
			<file_parent>1106</file_parent>
			<file_target>/Empty</file_target>
			<share_with/>
			<share_with_displayname>(Shared link)</share_with_displayname>
			<password/>
			<send_password_by_talk></send_password_by_talk>
			<url>http://localhost/nc/index.php/s/nALkbcS96tFmb5J</url>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>511</id>
			<share_type>3</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1563255688</stime>
			<parent/>
			<expiration/>
			<token>gDgMBDLNDNi8QWZ</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/utf8.txt</path>
			<item_type>file</item_type>
			<mimetype>text/plain</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>13607</item_source>
			<file_source>13607</file_source>
			<file_parent>103</file_parent>
			<file_target>/utf8.txt</file_target>
			<share_with/>
			<share_with_displayname>(Shared link)</share_with_displayname>
			<password/>
			<send_password_by_talk></send_password_by_talk>
			<url>http://localhost/nc/index.php/s/gDgMBDLNDNi8QWZ</url>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>517</id>
			<share_type>3</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1564047379</stime>
			<parent/>
			<expiration/>
			<token>eiA3NFgiAsKceXH</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/_1</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>22978</item_source>
			<file_source>22978</file_source>
			<file_parent>103</file_parent>
			<file_target>/_1</file_target>
			<share_with/>
			<share_with_displayname>(Shared link)</share_with_displayname>
			<password/>
			<send_password_by_talk></send_password_by_talk>
			<url>http://localhost/nc/index.php/s/eiA3NFgiAsKceXH</url>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>2320</id>
			<share_type>3</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>31</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1641448764</stime>
			<parent/>
			<expiration/>
			<token>RZWa8crJZNpWCEr</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/publicShare</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>227369</item_source>
			<file_source>227369</file_source>
			<file_parent>103</file_parent>
			<file_target>/publicShare</file_target>
			<share_with>34VShBw+POwkice/hxdDF77enYJUlA</share_with>
			<share_with_displayname>(Shared link)</share_with_displayname>
			<password>3+POwkice/hxdDF77enYJUlA</password>
			<send_password_by_talk></send_password_by_talk>
			<url>http://localhost/nc/index.php/s/RZWa8crJZNpWCEr</url>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>325</id>
			<share_type>4</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1528788256</stime>
			<parent/>
			<expiration/>
			<token>7d2wDEqfyN8NCmQ</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/_upload/20180427_111924.jpg</path>
			<item_type>file</item_type>
			<mimetype>image/jpeg</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>31691</item_source>
			<file_source>31691</file_source>
			<file_parent>31688</file_parent>
			<file_target></file_target>
			<share_with>tobias@kaminsky.me</share_with>
			<password>2+WntdypHiKNrswq80iGE</password>
			<password_expiration_time/>
			<send_password_by_talk></send_password_by_talk>
			<share_with_displayname>tobias@kaminsky.me</share_with_displayname>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>587</id>
			<share_type>4</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1572618149</stime>
			<parent/>
			<expiration/>
			<token>efkkH7qfmb2SWWC</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/allTypes/share/email</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>89053</item_source>
			<file_source>89053</file_source>
			<file_parent>21376</file_parent>
			<file_target></file_target>
			<share_with>tobias@kaminsky.me</share_with>
			<password/>
			<password_expiration_time/>
			<send_password_by_talk></send_password_by_talk>
			<share_with_displayname>tobias@kaminsky.me</share_with_displayname>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1263</id>
			<share_type>4</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>17</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1594036287</stime>
			<parent/>
			<expiration/>
			<token>nmwH6qcLxgDWBz6</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/all share types</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>131702</item_source>
			<file_source>131702</file_source>
			<file_parent>103</file_parent>
			<file_target></file_target>
			<share_with>tobias@kaminsky.me</share_with>
			<password/>
			<password_expiration_time/>
			<send_password_by_talk></send_password_by_talk>
			<share_with_displayname>tobias@kaminsky.me</share_with_displayname>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags>
				<element>_${'$'}!&lt;Favorite&gt;!$\_</element>
			</tags>
		</element>
		<element>
			<id>1271</id>
			<share_type>4</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>17</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1594125004</stime>
			<parent/>
			<expiration/>
			<token>mQC6BYb2gtbL6s7</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note>123</note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/all share types.md</path>
			<item_type>file</item_type>
			<mimetype>text/markdown</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>131782</item_source>
			<file_source>131782</file_source>
			<file_parent>103</file_parent>
			<file_target></file_target>
			<share_with>tobias@kaminsky.me</share_with>
			<password/>
			<password_expiration_time/>
			<send_password_by_talk></send_password_by_talk>
			<share_with_displayname>tobias@kaminsky.me</share_with_displayname>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags>
				<element>_${'$'}!&lt;Favorite&gt;!$\_</element>
			</tags>
		</element>
		<element>
			<id>1434</id>
			<share_type>4</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>17</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1599550329</stime>
			<parent/>
			<expiration/>
			<token>Kek2mafyoRXo4Nq</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label/>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/all share types.md</path>
			<item_type>file</item_type>
			<mimetype>text/markdown</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>131782</item_source>
			<file_source>131782</file_source>
			<file_parent>103</file_parent>
			<file_target></file_target>
			<share_with>test@remote.com</share_with>
			<password/>
			<password_expiration_time/>
			<send_password_by_talk></send_password_by_talk>
			<share_with_displayname>test@remote.com</share_with_displayname>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags>
				<element>_${'$'}!&lt;Favorite&gt;!$\_</element>
			</tags>
		</element>
		<element>
			<id>1260</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>31</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1593686024</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/allTypes/share/room</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>131755</item_source>
			<file_source>131755</file_source>
			<file_parent>21376</file_parent>
			<file_target>/{TALK_PLACEHOLDER}/room</file_target>
			<share_with>qehz3qsu</share_with>
			<share_with_displayname>Meeting</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/qehz3qsu</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1267</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>31</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1594036354</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/all share types</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>131702</item_source>
			<file_source>131702</file_source>
			<file_parent>103</file_parent>
			<file_target>/{TALK_PLACEHOLDER}/all share types</file_target>
			<share_with>qehz3qsu</share_with>
			<share_with_displayname>Meeting</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/qehz3qsu</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags>
				<element>_${'$'}!&lt;Favorite&gt;!$\_</element>
			</tags>
		</element>
		<element>
			<id>1469</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1602756682</stime>
			<parent/>
			<expiration/>
			<token>3x5yLbLfT86MjgR</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/all share types.md</path>
			<item_type>file</item_type>
			<mimetype>text/markdown</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>131782</item_source>
			<file_source>131782</file_source>
			<file_parent>103</file_parent>
			<file_target>/{TALK_PLACEHOLDER}/all share types.md</file_target>
			<share_with>wb98n9s3</share_with>
			<share_with_displayname>Kaminsky Tobi, admin</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/wb98n9s3</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags>
				<element>_${'$'}!&lt;Favorite&gt;!$\_</element>
			</tags>
		</element>
		<element>
			<id>1470</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1602756924</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/all share types.md</path>
			<item_type>file</item_type>
			<mimetype>text/markdown</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>131782</item_source>
			<file_source>131782</file_source>
			<file_parent>103</file_parent>
			<file_target>/{TALK_PLACEHOLDER}/all share types.md</file_target>
			<share_with>tcqbbead</share_with>
			<share_with_displayname>Administrator</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/tcqbbead</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags>
				<element>_${'$'}!&lt;Favorite&gt;!$\_</element>
			</tags>
		</element>
		<element>
			<id>1503</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>31</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1605795330</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/0123</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>20351</item_source>
			<file_source>20351</file_source>
			<file_parent>103</file_parent>
			<file_target>/{TALK_PLACEHOLDER}/0123</file_target>
			<share_with>qehz3qsu</share_with>
			<share_with_displayname>Meeting</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/qehz3qsu</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1666</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1616575054</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/04.gif</path>
			<item_type>file</item_type>
			<mimetype>image/gif</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>71907</item_source>
			<file_source>71907</file_source>
			<file_parent>103</file_parent>
			<file_target>/{TALK_PLACEHOLDER}/04.gif</file_target>
			<share_with>4oub6j6q</share_with>
			<share_with_displayname>Test Kaminsky</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/4oub6j6q</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1677</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1618979182</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Talk/IMG_20210407_173019244.png</path>
			<item_type>file</item_type>
			<mimetype>image/png</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>150784</item_source>
			<file_source>150784</file_source>
			<file_parent>131422</file_parent>
			<file_target>/{TALK_PLACEHOLDER}/IMG_20210407_173019244.png</file_target>
			<share_with>4oub6j6q</share_with>
			<share_with_displayname>Test Kaminsky</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/4oub6j6q</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1679</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1618985105</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Talk/nsmail.pdf</path>
			<item_type>file</item_type>
			<mimetype>application/pdf</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>150800</item_source>
			<file_source>150800</file_source>
			<file_parent>131422</file_parent>
			<file_target>/{TALK_PLACEHOLDER}/nsmail.pdf</file_target>
			<share_with>4oub6j6q</share_with>
			<share_with_displayname>Test Kaminsky</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/4oub6j6q</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1681</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1618987000</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/allTypes/bigImages/heic1816a.jpg</path>
			<item_type>file</item_type>
			<mimetype>image/jpeg</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>86351</item_source>
			<file_source>86351</file_source>
			<file_parent>86334</file_parent>
			<file_target>/{TALK_PLACEHOLDER}/heic1816a.jpg</file_target>
			<share_with>4oub6j6q</share_with>
			<share_with_displayname>Test Kaminsky</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/4oub6j6q</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1685</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1619071651</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Talk/Text File.txt</path>
			<item_type>file</item_type>
			<mimetype>text/plain</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>150932</item_source>
			<file_source>150932</file_source>
			<file_parent>131422</file_parent>
			<file_target>/{TALK_PLACEHOLDER}/Text File.txt</file_target>
			<share_with>4oub6j6q</share_with>
			<share_with_displayname>Test Kaminsky</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/4oub6j6q</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1746</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1623835170</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Talk/2021-06-16 11-19-25 (admin).wav</path>
			<item_type>file</item_type>
			<mimetype>audio/wav</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>163385</item_source>
			<file_source>163385</file_source>
			<file_parent>131422</file_parent>
			<file_target>/{TALK_PLACEHOLDER}/2021-06-16 11-19-25 (admin).wav</file_target>
			<share_with>xmz9k476</share_with>
			<share_with_displayname>admin</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/xmz9k476</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1749</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1623836577</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Talk/2021-06-16 11-42-53 (admin).wav</path>
			<item_type>file</item_type>
			<mimetype>audio/wav</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>163391</item_source>
			<file_source>163391</file_source>
			<file_parent>131422</file_parent>
			<file_target>/{TALK_PLACEHOLDER}/2021-06-16 11-42-53 (admin).wav</file_target>
			<share_with>xmz9k476</share_with>
			<share_with_displayname>admin</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/xmz9k476</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1750</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1623837046</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Talk/2021-06-16 11-50-44 (admin).wav</path>
			<item_type>file</item_type>
			<mimetype>audio/wav</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>163398</item_source>
			<file_source>163398</file_source>
			<file_parent>131422</file_parent>
			<file_target>/{TALK_PLACEHOLDER}/2021-06-16 11-50-44 (admin).wav</file_target>
			<share_with>xmz9k476</share_with>
			<share_with_displayname>admin</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/xmz9k476</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1751</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1623837295</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Talk/2021-06-16 11-54-53 (admin).wav</path>
			<item_type>file</item_type>
			<mimetype>audio/wav</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>163404</item_source>
			<file_source>163404</file_source>
			<file_parent>131422</file_parent>
			<file_target>/2021-06-16 11-54-53 (admin).wav</file_target>
			<share_with>xmz9k476</share_with>
			<share_with_displayname>admin</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/xmz9k476</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1752</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1623837323</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Talk/2021-06-16 11-55-21 (admin).wav</path>
			<item_type>file</item_type>
			<mimetype>audio/wav</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>163405</item_source>
			<file_source>163405</file_source>
			<file_parent>131422</file_parent>
			<file_target>/2021-06-16 11-55-21 (admin).wav</file_target>
			<share_with>xmz9k476</share_with>
			<share_with_displayname>admin</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/xmz9k476</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1753</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1623837357</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Talk/2021-06-16 11-55-56 (admin).wav</path>
			<item_type>file</item_type>
			<mimetype>audio/wav</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>163406</item_source>
			<file_source>163406</file_source>
			<file_parent>131422</file_parent>
			<file_target>/2021-06-16 11-55-56 (admin).wav</file_target>
			<share_with>xmz9k476</share_with>
			<share_with_displayname>admin</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/xmz9k476</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1754</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1623837365</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Talk/2021-06-16 11-56-03 (admin).wav</path>
			<item_type>file</item_type>
			<mimetype>audio/wav</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>163407</item_source>
			<file_source>163407</file_source>
			<file_parent>131422</file_parent>
			<file_target>/2021-06-16 11-56-03 (admin).wav</file_target>
			<share_with>xmz9k476</share_with>
			<share_with_displayname>admin</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/xmz9k476</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1755</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1623837377</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Talk/2021-06-16 11-56-15 (admin).wav</path>
			<item_type>file</item_type>
			<mimetype>audio/wav</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>163408</item_source>
			<file_source>163408</file_source>
			<file_parent>131422</file_parent>
			<file_target>/2021-06-16 11-56-15 (admin).wav</file_target>
			<share_with>xmz9k476</share_with>
			<share_with_displayname>admin</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/xmz9k476</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1756</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1623837403</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Talk/2021-06-16 11-56-41 (admin).wav</path>
			<item_type>file</item_type>
			<mimetype>audio/wav</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>163409</item_source>
			<file_source>163409</file_source>
			<file_parent>131422</file_parent>
			<file_target>/{TALK_PLACEHOLDER}/2021-06-16 11-56-41 (admin).wav</file_target>
			<share_with>xmz9k476</share_with>
			<share_with_displayname>admin</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/xmz9k476</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1757</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1623837444</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Talk/2021-06-16 11-57-22 (admin).wav</path>
			<item_type>file</item_type>
			<mimetype>audio/wav</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>163410</item_source>
			<file_source>163410</file_source>
			<file_parent>131422</file_parent>
			<file_target>/{TALK_PLACEHOLDER}/2021-06-16 11-57-22 (admin).wav</file_target>
			<share_with>xmz9k476</share_with>
			<share_with_displayname>admin</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/xmz9k476</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1758</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1623837501</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Talk/2021-06-16 11-58-20 (admin).wav</path>
			<item_type>file</item_type>
			<mimetype>audio/wav</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>163411</item_source>
			<file_source>163411</file_source>
			<file_parent>131422</file_parent>
			<file_target>/{TALK_PLACEHOLDER}/2021-06-16 11-58-20 (admin).wav</file_target>
			<share_with>xmz9k476</share_with>
			<share_with_displayname>admin</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/xmz9k476</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1759</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1623838177</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Talk/2021-06-16 12-09-35 (admin).wav</path>
			<item_type>file</item_type>
			<mimetype>audio/wav</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>163412</item_source>
			<file_source>163412</file_source>
			<file_parent>131422</file_parent>
			<file_target>/{TALK_PLACEHOLDER}/2021-06-16 12-09-35 (admin).wav</file_target>
			<share_with>xmz9k476</share_with>
			<share_with_displayname>admin</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/xmz9k476</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1760</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1623839109</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Talk/Talk recording from 2021-05-03 12-25-07 (admin).mp3</path>
			<item_type>file</item_type>
			<mimetype>audio/mpeg</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>163419</item_source>
			<file_source>163419</file_source>
			<file_parent>131422</file_parent>
			<file_target>/{TALK_PLACEHOLDER}/Talk recording from 2021-05-03 12-25-07 (admin).mp3</file_target>
			<share_with>xmz9k476</share_with>
			<share_with_displayname>admin</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/xmz9k476</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1761</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1623839136</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Talk/Talk recording from 2021-05-03 12-25-35 (admin).mp3</path>
			<item_type>file</item_type>
			<mimetype>audio/mpeg</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>163424</item_source>
			<file_source>163424</file_source>
			<file_parent>131422</file_parent>
			<file_target>/{TALK_PLACEHOLDER}/Talk recording from 2021-05-03 12-25-35 (admin).mp3</file_target>
			<share_with>xmz9k476</share_with>
			<share_with_displayname>admin</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/xmz9k476</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1762</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1623839363</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Talk/2021-06-16 12-29-21 (admin).wav</path>
			<item_type>file</item_type>
			<mimetype>audio/wav</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>163430</item_source>
			<file_source>163430</file_source>
			<file_parent>131422</file_parent>
			<file_target>/{TALK_PLACEHOLDER}/2021-06-16 12-29-21 (admin).wav</file_target>
			<share_with>xmz9k476</share_with>
			<share_with_displayname>admin</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/xmz9k476</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1763</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1623839384</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Talk/2021-06-16 12-29-42 (admin).wav</path>
			<item_type>file</item_type>
			<mimetype>audio/wav</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>163431</item_source>
			<file_source>163431</file_source>
			<file_parent>131422</file_parent>
			<file_target>/{TALK_PLACEHOLDER}/2021-06-16 12-29-42 (admin).wav</file_target>
			<share_with>xmz9k476</share_with>
			<share_with_displayname>admin</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/xmz9k476</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1764</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1623839512</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Talk/2021-06-16 12-31-51 (admin).wav</path>
			<item_type>file</item_type>
			<mimetype>audio/wav</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>163432</item_source>
			<file_source>163432</file_source>
			<file_parent>131422</file_parent>
			<file_target>/{TALK_PLACEHOLDER}/2021-06-16 12-31-51 (admin).wav</file_target>
			<share_with>xmz9k476</share_with>
			<share_with_displayname>admin</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/xmz9k476</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1765</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1623839534</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Talk/2021-06-16 12-32-12 (admin).wav</path>
			<item_type>file</item_type>
			<mimetype>audio/wav</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>163433</item_source>
			<file_source>163433</file_source>
			<file_parent>131422</file_parent>
			<file_target>/{TALK_PLACEHOLDER}/2021-06-16 12-32-12 (admin).wav</file_target>
			<share_with>xmz9k476</share_with>
			<share_with_displayname>admin</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/xmz9k476</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1766</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1623839558</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Talk/2021-06-16 12-32-36 (admin).wav</path>
			<item_type>file</item_type>
			<mimetype>audio/wav</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>163439</item_source>
			<file_source>163439</file_source>
			<file_parent>131422</file_parent>
			<file_target>/{TALK_PLACEHOLDER}/2021-06-16 12-32-36 (admin).wav</file_target>
			<share_with>xmz9k476</share_with>
			<share_with_displayname>admin</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/xmz9k476</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1767</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1623839601</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Talk/2021-06-16 12-33-19 (admin).wav</path>
			<item_type>file</item_type>
			<mimetype>audio/wav</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>163446</item_source>
			<file_source>163446</file_source>
			<file_parent>131422</file_parent>
			<file_target>/{TALK_PLACEHOLDER}/2021-06-16 12-33-19 (admin).wav</file_target>
			<share_with>xmz9k476</share_with>
			<share_with_displayname>admin</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/xmz9k476</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1768</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1623839632</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Talk/2021-06-16 12-33-51 (admin).wav</path>
			<item_type>file</item_type>
			<mimetype>audio/wav</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>163453</item_source>
			<file_source>163453</file_source>
			<file_parent>131422</file_parent>
			<file_target>/{TALK_PLACEHOLDER}/2021-06-16 12-33-51 (admin).wav</file_target>
			<share_with>xmz9k476</share_with>
			<share_with_displayname>admin</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/xmz9k476</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1769</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1623839890</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Talk/2021-06-16 12-38-08 (admin).wav</path>
			<item_type>file</item_type>
			<mimetype>audio/wav</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>163459</item_source>
			<file_source>163459</file_source>
			<file_parent>131422</file_parent>
			<file_target>/{TALK_PLACEHOLDER}/2021-06-16 12-38-08 (admin).wav</file_target>
			<share_with>xmz9k476</share_with>
			<share_with_displayname>admin</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/xmz9k476</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1770</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1623839963</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Talk/2021-06-16 12-39-21 (admin).wav</path>
			<item_type>file</item_type>
			<mimetype>audio/wav</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>163466</item_source>
			<file_source>163466</file_source>
			<file_parent>131422</file_parent>
			<file_target>/{TALK_PLACEHOLDER}/2021-06-16 12-39-21 (admin).wav</file_target>
			<share_with>xmz9k476</share_with>
			<share_with_displayname>admin</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/xmz9k476</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1771</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1623839995</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Talk/2021-06-16 12-39-54 (admin).wav</path>
			<item_type>file</item_type>
			<mimetype>audio/wav</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>163473</item_source>
			<file_source>163473</file_source>
			<file_parent>131422</file_parent>
			<file_target>/{TALK_PLACEHOLDER}/2021-06-16 12-39-54 (admin).wav</file_target>
			<share_with>xmz9k476</share_with>
			<share_with_displayname>admin</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/xmz9k476</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1772</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1623840029</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Talk/2021-06-16 12-40-28 (admin).wav</path>
			<item_type>file</item_type>
			<mimetype>audio/wav</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>163479</item_source>
			<file_source>163479</file_source>
			<file_parent>131422</file_parent>
			<file_target>/{TALK_PLACEHOLDER}/2021-06-16 12-40-28 (admin).wav</file_target>
			<share_with>xmz9k476</share_with>
			<share_with_displayname>admin</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/xmz9k476</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1773</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1623840074</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Talk/2021-06-16 12-41-12 (admin).wav</path>
			<item_type>file</item_type>
			<mimetype>audio/wav</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>163484</item_source>
			<file_source>163484</file_source>
			<file_parent>131422</file_parent>
			<file_target>/{TALK_PLACEHOLDER}/2021-06-16 12-41-12 (admin).wav</file_target>
			<share_with>xmz9k476</share_with>
			<share_with_displayname>admin</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/xmz9k476</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1774</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1623840096</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Talk/2021-06-16 12-41-35 (admin).wav</path>
			<item_type>file</item_type>
			<mimetype>audio/wav</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>163491</item_source>
			<file_source>163491</file_source>
			<file_parent>131422</file_parent>
			<file_target>/{TALK_PLACEHOLDER}/2021-06-16 12-41-35 (admin).wav</file_target>
			<share_with>xmz9k476</share_with>
			<share_with_displayname>admin</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/xmz9k476</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1775</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1623840165</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Talk/2021-06-16 12-42-43 (admin).wav</path>
			<item_type>file</item_type>
			<mimetype>audio/wav</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>163497</item_source>
			<file_source>163497</file_source>
			<file_parent>131422</file_parent>
			<file_target>/{TALK_PLACEHOLDER}/2021-06-16 12-42-43 (admin).wav</file_target>
			<share_with>xmz9k476</share_with>
			<share_with_displayname>admin</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/xmz9k476</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1776</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1623840224</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Talk/2021-06-16 12-43-43 (admin).wav</path>
			<item_type>file</item_type>
			<mimetype>audio/wav</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>163504</item_source>
			<file_source>163504</file_source>
			<file_parent>131422</file_parent>
			<file_target>/{TALK_PLACEHOLDER}/2021-06-16 12-43-43 (admin).wav</file_target>
			<share_with>xmz9k476</share_with>
			<share_with_displayname>admin</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/xmz9k476</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1777</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1623840273</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Talk/2021-06-16 12-44-32 (admin).wav</path>
			<item_type>file</item_type>
			<mimetype>audio/wav</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>163510</item_source>
			<file_source>163510</file_source>
			<file_parent>131422</file_parent>
			<file_target>/{TALK_PLACEHOLDER}/2021-06-16 12-44-32 (admin).wav</file_target>
			<share_with>xmz9k476</share_with>
			<share_with_displayname>admin</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/xmz9k476</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1778</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1623840313</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Talk/2021-06-16 12-45-11 (admin).wav</path>
			<item_type>file</item_type>
			<mimetype>audio/wav</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>163511</item_source>
			<file_source>163511</file_source>
			<file_parent>131422</file_parent>
			<file_target>/{TALK_PLACEHOLDER}/2021-06-16 12-45-11 (admin).wav</file_target>
			<share_with>xmz9k476</share_with>
			<share_with_displayname>admin</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/xmz9k476</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1779</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1623840337</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Talk/2021-06-16 12-45-36 (admin).wav</path>
			<item_type>file</item_type>
			<mimetype>audio/wav</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>163518</item_source>
			<file_source>163518</file_source>
			<file_parent>131422</file_parent>
			<file_target>/{TALK_PLACEHOLDER}/2021-06-16 12-45-36 (admin).wav</file_target>
			<share_with>xmz9k476</share_with>
			<share_with_displayname>admin</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/xmz9k476</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1780</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1623840379</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Talk/2021-06-16 12-46-18 (admin).wav</path>
			<item_type>file</item_type>
			<mimetype>audio/wav</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>163524</item_source>
			<file_source>163524</file_source>
			<file_parent>131422</file_parent>
			<file_target>/{TALK_PLACEHOLDER}/2021-06-16 12-46-18 (admin).wav</file_target>
			<share_with>xmz9k476</share_with>
			<share_with_displayname>admin</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/xmz9k476</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1781</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1623840428</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Talk/2021-06-16 12-47-07 (admin).wav</path>
			<item_type>file</item_type>
			<mimetype>audio/wav</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>163531</item_source>
			<file_source>163531</file_source>
			<file_parent>131422</file_parent>
			<file_target>/2021-06-16 12-47-07 (admin).wav</file_target>
			<share_with>xmz9k476</share_with>
			<share_with_displayname>admin</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/xmz9k476</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1782</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1623840430</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Talk/2021-06-16 12-47-09 (admin).wav</path>
			<item_type>file</item_type>
			<mimetype>audio/wav</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>163532</item_source>
			<file_source>163532</file_source>
			<file_parent>131422</file_parent>
			<file_target>/2021-06-16 12-47-09 (admin).wav</file_target>
			<share_with>xmz9k476</share_with>
			<share_with_displayname>admin</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/xmz9k476</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1783</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1623840442</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Talk/2021-06-16 12-47-21 (admin).wav</path>
			<item_type>file</item_type>
			<mimetype>audio/wav</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>163533</item_source>
			<file_source>163533</file_source>
			<file_parent>131422</file_parent>
			<file_target>/{TALK_PLACEHOLDER}/2021-06-16 12-47-21 (admin).wav</file_target>
			<share_with>xmz9k476</share_with>
			<share_with_displayname>admin</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/xmz9k476</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1784</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1623840443</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Talk/2021-06-16 12-47-22 (admin).wav</path>
			<item_type>file</item_type>
			<mimetype>audio/wav</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>163534</item_source>
			<file_source>163534</file_source>
			<file_parent>131422</file_parent>
			<file_target>/{TALK_PLACEHOLDER}/2021-06-16 12-47-22 (admin).wav</file_target>
			<share_with>xmz9k476</share_with>
			<share_with_displayname>admin</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/xmz9k476</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1785</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1623840467</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Talk/2021-06-16 12-47-46 (admin).wav</path>
			<item_type>file</item_type>
			<mimetype>audio/wav</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>163545</item_source>
			<file_source>163545</file_source>
			<file_parent>131422</file_parent>
			<file_target>/{TALK_PLACEHOLDER}/2021-06-16 12-47-46 (admin).wav</file_target>
			<share_with>xmz9k476</share_with>
			<share_with_displayname>admin</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/xmz9k476</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1786</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1623914113</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Talk/2021-06-17 09-15-11 (admin).wav</path>
			<item_type>file</item_type>
			<mimetype>audio/wav</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>163558</item_source>
			<file_source>163558</file_source>
			<file_parent>131422</file_parent>
			<file_target>/{TALK_PLACEHOLDER}/2021-06-17 09-15-11 (admin).wav</file_target>
			<share_with>xmz9k476</share_with>
			<share_with_displayname>admin</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/xmz9k476</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1822</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1623914303</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Talk/2021-06-17 09-18-23 (admin).wav</path>
			<item_type>file</item_type>
			<mimetype>audio/wav</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>163571</item_source>
			<file_source>163571</file_source>
			<file_parent>131422</file_parent>
			<file_target>/{TALK_PLACEHOLDER}/2021-06-17 09-18-23 (admin).wav</file_target>
			<share_with>xmz9k476</share_with>
			<share_with_displayname>admin</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/xmz9k476</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1824</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1623914306</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Talk/2021-06-17 09-18-24 (admin).wav</path>
			<item_type>file</item_type>
			<mimetype>audio/wav</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>163572</item_source>
			<file_source>163572</file_source>
			<file_parent>131422</file_parent>
			<file_target>/{TALK_PLACEHOLDER}/2021-06-17 09-18-24 (admin).wav</file_target>
			<share_with>xmz9k476</share_with>
			<share_with_displayname>admin</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/xmz9k476</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1826</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1623914310</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Talk/2021-06-17 09-18-28 (admin).wav</path>
			<item_type>file</item_type>
			<mimetype>audio/wav</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>163573</item_source>
			<file_source>163573</file_source>
			<file_parent>131422</file_parent>
			<file_target>/{TALK_PLACEHOLDER}/2021-06-17 09-18-28 (admin).wav</file_target>
			<share_with>xmz9k476</share_with>
			<share_with_displayname>admin</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/xmz9k476</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1828</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1623914421</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Talk/Talk recording from 2021-06-17 09-20-19 (admin).mp3</path>
			<item_type>file</item_type>
			<mimetype>audio/mpeg</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>163574</item_source>
			<file_source>163574</file_source>
			<file_parent>131422</file_parent>
			<file_target>/{TALK_PLACEHOLDER}/Talk recording from 2021-06-17 09-20-19 (admin).mp3</file_target>
			<share_with>xmz9k476</share_with>
			<share_with_displayname>admin</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/xmz9k476</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1830</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1623914654</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Talk/Talk recording from 2021-06-17 09-24-08 (admin).mp3</path>
			<item_type>file</item_type>
			<mimetype>audio/mpeg</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>163581</item_source>
			<file_source>163581</file_source>
			<file_parent>131422</file_parent>
			<file_target>/{TALK_PLACEHOLDER}/Talk recording from 2021-06-17 09-24-08 (admin).mp3</file_target>
			<share_with>xmz9k476</share_with>
			<share_with_displayname>admin</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/xmz9k476</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1832</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1623915404</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Talk/Talk recording from 2021-06-17 09-36-38 (admin).mp3</path>
			<item_type>file</item_type>
			<mimetype>audio/mpeg</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>163588</item_source>
			<file_source>163588</file_source>
			<file_parent>131422</file_parent>
			<file_target>/{TALK_PLACEHOLDER}/Talk recording from 2021-06-17 09-36-38 (admin).mp3</file_target>
			<share_with>xmz9k476</share_with>
			<share_with_displayname>admin</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/xmz9k476</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1834</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1623915571</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Talk/Talk recording from 2021-06-17 09-39-22 (admin).mp3</path>
			<item_type>file</item_type>
			<mimetype>audio/mpeg</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>163595</item_source>
			<file_source>163595</file_source>
			<file_parent>131422</file_parent>
			<file_target>/{TALK_PLACEHOLDER}/Talk recording from 2021-06-17 09-39-22 (admin).mp3</file_target>
			<share_with>xmz9k476</share_with>
			<share_with_displayname>admin</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/xmz9k476</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1836</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1623916316</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Talk/Talk recording from 2021-06-17 09-51-52 (admin).mp3</path>
			<item_type>file</item_type>
			<mimetype>audio/mpeg</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>163596</item_source>
			<file_source>163596</file_source>
			<file_parent>131422</file_parent>
			<file_target>/{TALK_PLACEHOLDER}/Talk recording from 2021-06-17 09-51-52 (admin).mp3</file_target>
			<share_with>xmz9k476</share_with>
			<share_with_displayname>admin</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/xmz9k476</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1838</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1623916498</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Talk/Talk recording from 2021-06-17 09-54-55 (admin).mp3</path>
			<item_type>file</item_type>
			<mimetype>audio/mpeg</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>163605</item_source>
			<file_source>163605</file_source>
			<file_parent>131422</file_parent>
			<file_target>/{TALK_PLACEHOLDER}/Talk recording from 2021-06-17 09-54-55 (admin).mp3</file_target>
			<share_with>xmz9k476</share_with>
			<share_with_displayname>admin</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/xmz9k476</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1840</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1623916665</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Talk/Talk recording from 2021-06-17 09-56-45 (admin).mp3</path>
			<item_type>file</item_type>
			<mimetype>audio/mpeg</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>163621</item_source>
			<file_source>163621</file_source>
			<file_parent>131422</file_parent>
			<file_target>/{TALK_PLACEHOLDER}/Talk recording from 2021-06-17 09-56-45 (admin).mp3</file_target>
			<share_with>xmz9k476</share_with>
			<share_with_displayname>admin</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/xmz9k476</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1842</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1623916715</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Talk/Talk recording from 2021-06-17 09-58-30 (admin).mp3</path>
			<item_type>file</item_type>
			<mimetype>audio/mpeg</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>163622</item_source>
			<file_source>163622</file_source>
			<file_parent>131422</file_parent>
			<file_target>/{TALK_PLACEHOLDER}/Talk recording from 2021-06-17 09-58-30 (admin).mp3</file_target>
			<share_with>xmz9k476</share_with>
			<share_with_displayname>admin</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/xmz9k476</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1844</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1623916790</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Talk/Talk recording from 2021-06-17 09-59-40 (admin).mp3</path>
			<item_type>file</item_type>
			<mimetype>audio/mpeg</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>163633</item_source>
			<file_source>163633</file_source>
			<file_parent>131422</file_parent>
			<file_target>/{TALK_PLACEHOLDER}/Talk recording from 2021-06-17 09-59-40 (admin).mp3</file_target>
			<share_with>xmz9k476</share_with>
			<share_with_displayname>admin</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/xmz9k476</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1846</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1623917333</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Talk/Talk recording from 2021-06-17 10-08-21 (admin).mp3</path>
			<item_type>file</item_type>
			<mimetype>audio/mpeg</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>163639</item_source>
			<file_source>163639</file_source>
			<file_parent>131422</file_parent>
			<file_target>/{TALK_PLACEHOLDER}/Talk recording from 2021-06-17 10-08-21 (admin).mp3</file_target>
			<share_with>xmz9k476</share_with>
			<share_with_displayname>admin</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/xmz9k476</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>2023</id>
			<share_type>10</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>1</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1629973490</stime>
			<parent/>
			<expiration/>
			<token/>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/Talk/IMG_20210407_173414562.jpg</path>
			<item_type>file</item_type>
			<mimetype>image/jpeg</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>195632</item_source>
			<file_source>195632</file_source>
			<file_parent>131422</file_parent>
			<file_target>/{TALK_PLACEHOLDER}/IMG_20210407_173414562.jpg</file_target>
			<share_with>4oub6j6q</share_with>
			<share_with_displayname>Test Kaminsky</share_with_displayname>
			<share_with_link>http://localhost/nc/index.php/call/4oub6j6q</share_with_link>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>345</id>
			<share_type>6</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1535116166</stime>
			<parent/>
			<expiration/>
			<token>COPBlidtTwDCpQN</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/_hidden/.hidden.gif</path>
			<item_type>file</item_type>
			<mimetype>image/gif</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>36490</item_source>
			<file_source>36490</file_source>
			<file_parent>36473</file_parent>
			<file_target></file_target>
			<share_with>test@nextcloud.kaminsky.me</share_with>
			<share_with_displayname>test@nextcloud.kaminsky.me</share_with_displayname>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>407</id>
			<share_type>6</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>31</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1551275377</stime>
			<parent/>
			<expiration/>
			<token>PmnLm2KagKXWFx0</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/allTypes/share/federated share by me</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>77039</item_source>
			<file_source>77039</file_source>
			<file_parent>21376</file_parent>
			<file_target></file_target>
			<share_with>tobi@http://localhost/nc15</share_with>
			<share_with_displayname>tobi@http://localhost/nc15</share_with_displayname>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>415</id>
			<share_type>6</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>3</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1551952500</stime>
			<parent/>
			<expiration/>
			<token>BhlLrDFUYguRi1D</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/1_Photos/Squirrel.jpg</path>
			<item_type>file</item_type>
			<mimetype>image/jpeg</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>871</item_source>
			<file_source>871</file_source>
			<file_parent>851</file_parent>
			<file_target></file_target>
			<share_with>tobias@cloud.nextcloud.com</share_with>
			<share_with_displayname>tobias@cloud.nextcloud.com</share_with_displayname>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>436</id>
			<share_type>6</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1554986670</stime>
			<parent/>
			<expiration/>
			<token>0kQLJytOkmykgo0</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/123123.txt</path>
			<item_type>file</item_type>
			<mimetype>text/plain</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>81104</item_source>
			<file_source>81104</file_source>
			<file_parent>103</file_parent>
			<file_target></file_target>
			<share_with>tobi@http://localhost/nc15</share_with>
			<share_with_displayname>tobi@http://localhost/nc15</share_with_displayname>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1268</id>
			<share_type>6</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>31</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1594036374</stime>
			<parent/>
			<expiration/>
			<token>exZgHf7MC374LZ5</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/all share types</path>
			<item_type>folder</item_type>
			<mimetype>httpd/unix-directory</mimetype>
			<has_preview></has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>131702</item_source>
			<file_source>131702</file_source>
			<file_parent>103</file_parent>
			<file_target></file_target>
			<share_with>test@nextcloud.kaminsky.me</share_with>
			<share_with_displayname>test@nextcloud.kaminsky.me</share_with_displayname>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags>
				<element>_${'$'}!&lt;Favorite&gt;!$\_</element>
			</tags>
		</element>
		<element>
			<id>1598</id>
			<share_type>6</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1613139126</stime>
			<parent/>
			<expiration/>
			<token>SnZqjpiq1fo7z9r</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/IMG_20160925_124718 (2).jpg</path>
			<item_type>file</item_type>
			<mimetype>image/jpeg</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>983</item_source>
			<file_source>983</file_source>
			<file_parent>103</file_parent>
			<file_target></file_target>
			<share_with>tobias.kaminsky@tafaul.gov.sa</share_with>
			<share_with_displayname>tobias.kaminsky@tafaul.gov.sa</share_with_displayname>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1599</id>
			<share_type>6</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1613139241</stime>
			<parent/>
			<expiration/>
			<token>TsR7aFTSjemDYfQ</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/IMG_20160925_124718.jpg</path>
			<item_type>file</item_type>
			<mimetype>image/jpeg</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>979</item_source>
			<file_source>979</file_source>
			<file_parent>103</file_parent>
			<file_target></file_target>
			<share_with>tobias.kaminsky@tafaul.gov.sa</share_with>
			<share_with_displayname>tobias.kaminsky@tafaul.gov.sa</share_with_displayname>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags/>
		</element>
		<element>
			<id>1435</id>
			<share_type>9</share_type>
			<uid_owner>tobi</uid_owner>
			<displayname_owner>Tobi K</displayname_owner>
			<permissions>19</permissions>
			<can_edit>1</can_edit>
			<can_delete>1</can_delete>
			<stime>1599550381</stime>
			<parent/>
			<expiration/>
			<token>vqhhsusYpHU8sPA</token>
			<uid_file_owner>tobi</uid_file_owner>
			<note></note>
			<label></label>
			<displayname_file_owner>Tobi K</displayname_file_owner>
			<path>/all share types.md</path>
			<item_type>file</item_type>
			<mimetype>text/markdown</mimetype>
			<has_preview>1</has_preview>
			<storage_id>home::tobi</storage_id>
			<storage>3</storage>
			<item_source>131782</item_source>
			<file_source>131782</file_source>
			<file_parent>103</file_parent>
			<file_target></file_target>
			<share_with>test@nextcloud.kaminsky.me</share_with>
			<share_with_displayname>test@nextcloud.kaminsky.me</share_with_displayname>
			<mail_send>0</mail_send>
			<hide_download>0</hide_download>
			<attributes/>
			<tags>
				<element>_${'$'}!&lt;Favorite&gt;!$\_</element>
			</tags>
		</element>
	</data>
</ocs>
"""
        val sut = ShareToRemoteOperationResultParser(ShareXMLParser())
        val shares = sut.parse(xml)

        assertEquals(201, shares.resultData.size)
        assertEquals(21, shares.resultData.count { ocShare -> ocShare.isFavorite })
    }
}
